@@ -24,6 +24,9 @@
  * Author: INdT - Renato Araujo <renato.filho@indt.org.br>
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
 #include <gtk/gtk.h>
 #include <gdk/gdk.h>
@@ -53,9 +56,9 @@
 #include "xap_UnixDialogHelper.h"
 #include "ap_Menu_Id.h"
 // hack, icons are in wp
-#include "../../../wp/ap/unix/ap_UnixStockIcons.h"
+#include "ap_UnixStockIcons.h"
 #if defined(EMBEDDED_TARGET) && EMBEDDED_TARGET == EMBEDDED_TARGET_HILDON
-#include <hildon-widgets/hildon-appview.h>
+#include <hildon/hildon-window.h>
 #endif
 
 #define ACTIVATE_ACCEL "activate"
@@ -227,8 +230,8 @@ static const char ** _ev_GetLabelName(XAP_UnixApp * pUnixApp,
 
 	// append "..." to menu item if it raises a dialog
 	static char buf[128];
-	memset(buf,0,NrElements(buf));
-	strncpy(buf,szLabelName,NrElements(buf)-4);
+	memset(buf,0,G_N_ELEMENTS(buf));
+	strncpy(buf,szLabelName,G_N_ELEMENTS(buf)-4);
 	strcat(buf,"...");
 
 	data[0] = buf;
@@ -551,7 +554,7 @@ bool EV_UnixMenu::synthesizeMenu(GtkWidget * wMenuRoot, bool isPopup)
 					FREEP(dup);
 				}
 
-#ifndef EMBEDDED_MENUBUTTON
+#ifndef ENABLE_MENUBUTTON
 				if ((keyCode != GDK_VoidSymbol) && !isPopup)
 				  {
 					  // bind to top level if parent is top level
@@ -952,8 +955,9 @@ bool EV_UnixMenuBar::synthesizeMenuBar()
 	// Just create, don't show the menu bar yet.  It is later added and shown
 #if defined(EMBEDDED_TARGET) && EMBEDDED_TARGET == EMBEDDED_TARGET_HILDON /* in hildon sdk you have get menu_bar from mainWidonw */
 	GtkWidget * wWidget = static_cast<XAP_UnixFrameImpl *>(m_pFrame->getFrameImpl())->getTopLevelWindow();
-	m_wMenuBar = GTK_WIDGET(hildon_appview_get_menu(HILDON_APPVIEW(wWidget)));
-#elif defined (EMBEDDED_MENUBUTTON)
+	m_wMenuBar = gtk_menu_new ();
+    hildon_window_set_menu (HILDON_WINDOW (wWidget), GTK_MENU (m_wMenuBar));
+#elif defined (ENABLE_MENUBUTTON)
 	m_wMenuBar = gtk_menu_new ();
 #else
 	GtkWidget * wVBox = static_cast<XAP_UnixFrameImpl *>(m_pFrame->getFrameImpl())->getVBoxWidget();
@@ -979,7 +983,7 @@ bool EV_UnixMenuBar::rebuildMenuBar()
 
 	// Just create, don't show the menu bar yet.  It is later added
 	// to a 3D handle box and shown
-#ifdef EMBEDDED_MENUBUTTON
+#ifdef ENABLE_MENUBUTTON
 	m_wMenuBar = gtk_menu_new();
 #else
 	m_wMenuBar = gtk_menu_bar_new();
