@@ -25,6 +25,10 @@
  * Author: INdT - Renato Araujo <renato.filho@indt.org.br>
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <gtk/gtk.h>
 #include <goffice/gtk/go-combo-box.h>
 #include <goffice/gtk/go-combo-color.h>
@@ -57,12 +61,12 @@
 #include "ap_UnixStockIcons.h"
 #include "ev_UnixFontCombo.h"
 
-#ifdef EMBEDDED_MENUBUTTON
+#ifdef ENABLE_MENUBUTTON
 #include "ev_UnixMenuBar.h"
 #endif
 
 #if defined(EMBEDDED_TARGET) && EMBEDDED_TARGET == EMBEDDED_TARGET_HILDON
-#include "hildon-widgets/hildon-appview.h"
+#include <hildon/hildon-window.h>
 #endif
 
 #define PROP_HANDLER_ID "handler-id"
@@ -71,7 +75,7 @@ class _wd;
 
 static void s_proxy_activated(GtkAction * action, _wd * wd);
 
-static const GtkTargetEntry s_AbiTBTargets[] = {{"abi-toolbars",0,0}};
+static const GtkTargetEntry s_AbiTBTargets[] = {{(gchar*)"abi-toolbars",0,0}};
 
 /*!
  * Append a widget to the toolbar, 
@@ -177,7 +181,7 @@ toolbar_append_toggle (GtkToolbar 	*toolbar,
 											  NULL, NULL, NULL);
 }
 
-#ifdef EMBEDDED_MENUBUTTON
+#ifdef ENABLE_MENUBUTTON
 static void
 menubutton_show_cb (GtkWidget *widget, gpointer data)
 {
@@ -841,7 +845,7 @@ bool EV_UnixToolbar::synthesize(void)
 					UT_UTF8String sCancel;
 					pSS->getValueUTF8(XAP_STRING_ID_DLG_Cancel,sCancel);
 
-					abi_table_set_labels(ABITABLE_WIDGET(abi_table),const_cast<gchar *>(sTable.utf8_str()),const_cast<gchar *>(sCancel.utf8_str()));
+					abi_table_set_labels(ABITABLE_WIDGET(abi_table),sTable.utf8_str(),sCancel.utf8_str());
 					gtk_widget_show(abi_table);
 					UT_DEBUGMSG(("SEVIOR: Made insert table widget \n"));
 					wd->m_handlerId = g_signal_connect(abi_table, "selected",
@@ -1080,7 +1084,7 @@ bool EV_UnixToolbar::synthesize(void)
 			case EV_TBIT_Spacer:
 				break;
 
-#ifdef EMBEDDED_MENUBUTTON
+#ifdef ENABLE_MENUBUTTON
 			case EV_TBIT_MenuButton:
 			{
 				GtkWidget * wMenu = NULL;
@@ -1138,12 +1142,10 @@ bool EV_UnixToolbar::synthesize(void)
 	}
 
 #if defined(EMBEDDED_TARGET) && EMBEDDED_TARGET == EMBEDDED_TARGET_HILDON
-	
 	GtkWidget * wTLW = static_cast<XAP_UnixFrameImpl *>(m_pFrame->getFrameImpl())->getTopLevelWindow();
-	gtk_box_pack_end(GTK_BOX(HILDON_APPVIEW(wTLW)->vbox), m_wToolbar, FALSE, FALSE, 0);
-	gtk_widget_show_all(m_wToolbar);	
-	gtk_widget_show_all(wTLW);			
-
+	hildon_window_add_toolbar (HILDON_WINDOW (wTLW), GTK_TOOLBAR (m_wToolbar));
+	gtk_widget_show_all(m_wToolbar);
+	gtk_widget_show_all(wTLW);
 #else
 	GtkBox * wBox = _getContainer();
 
