@@ -18,6 +18,7 @@
  */
 
 #define WIN32_LEAN_AND_MEAN
+
 #include <windows.h>
 #define _WIN32_IE 0x0300 // specify minimal comctl.dll v4.70 for toolbars
 #include <commctrl.h>   // includes the common control header
@@ -585,11 +586,7 @@ bool EV_Win32Toolbar::synthesize(void)
 	for (UT_uint32 k=0; (k < nrLabelItemsInLayout); k++)
 	{
 		EV_Toolbar_LayoutItem * pLayoutItem = m_pToolbarLayout->getLayoutItem(k);
-		if(!pLayoutItem)
-		{
-			UT_ASSERT_HARMLESS(pLayoutItem);
-			continue;
-		}
+		UT_continue_if_fail(pLayoutItem);
 
 		XAP_Toolbar_Id id = pLayoutItem->getToolbarId();
 		EV_Toolbar_Action * pAction = pToolbarActionSet->getAction(id);
@@ -856,15 +853,11 @@ bool EV_Win32Toolbar::synthesize(void)
 		for (UT_uint32 k=0; (k < nrLabelItemsInLayout); k++)
 		{
 			EV_Toolbar_LayoutItem * pLayoutItem = m_pToolbarLayout->getLayoutItem(k);
-			if(!pLayoutItem)
-			{
-				UT_ASSERT_HARMLESS(pLayoutItem);
-				continue;
-			}
+			UT_continue_if_fail(pLayoutItem);
 
 			XAP_Toolbar_Id id = pLayoutItem->getToolbarId();
 			EV_Toolbar_Action * pAction = pToolbarActionSet->getAction(id);
-			UT_ASSERT(pAction);
+			UT_continue_if_fail(pAction);
 
 			RECT r;
 			HWND hwndCtrl;
@@ -977,19 +970,11 @@ bool EV_Win32Toolbar::refreshToolbar(AV_View * pView, AV_ChangeMask mask)
 	for (UT_uint32 k=0; (k < nrLabelItemsInLayout); k++)
 	{
 		EV_Toolbar_LayoutItem * pLayoutItem = m_pToolbarLayout->getLayoutItem(k);
-		if(!pLayoutItem)
-		{
-			UT_ASSERT_HARMLESS(pLayoutItem);
-			continue;
-		}
+		UT_continue_if_fail(pLayoutItem);
 
 		XAP_Toolbar_Id id = pLayoutItem->getToolbarId();
 		EV_Toolbar_Action * pAction = pToolbarActionSet->getAction(id);
-		if(!pAction)
-		{
-			UT_ASSERT_HARMLESS(pAction);
-			continue;
-		}
+		UT_continue_if_fail(pAction);
 
 		AV_ChangeMask maskOfInterest = pAction->getChangeMaskOfInterest();
 		if ((maskOfInterest & mask) == 0)					// if this item doesn't care about
@@ -1348,6 +1333,7 @@ bool EV_Win32Toolbar::repopulateStyles(void)
 // list of styles to the combo box.
 //
 // Try this....
+	SendMessage(hwndCombo, WM_SETREDRAW, FALSE, 0);
 	SendMessage(hwndCombo, CB_RESETCONTENT, 0 , 0);
 
 	SendMessage(hwndCombo, CB_SETDROPPEDWIDTH,
@@ -1386,6 +1372,8 @@ bool EV_Win32Toolbar::repopulateStyles(void)
 //
 // Don't need this anymore and we don't like memory leaks in abi
 //
+	SendMessage(hwndCombo, WM_SETREDRAW, TRUE, 0);
+	InvalidateRect (hwndCombo, NULL, true);
 	delete pStyleC;
 //
 // I think we've finished!
