@@ -21,6 +21,10 @@
 #ifndef GR_UNIX_PANGOGRAPHICS_H
 #define GR_UNIX_PANGOGRAPHICS_H
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <vector>
 
 #include "ut_types.h"
@@ -34,7 +38,7 @@
 
 #include <X11/Xft/Xft.h>
 
-#ifndef WITHOUT_PRINTING
+#ifdef ENABLE_PRINT
 #include <libgnomeprint/gnome-print.h>
 #include <libgnomeprint/gnome-print-job.h>
 #endif
@@ -111,12 +115,12 @@ class GR_UnixAllocInfo : public GR_AllocInfo
 public:
  	GR_UnixAllocInfo(GdkWindow * win)
 		: m_win(win),
-#ifndef WITHOUT_PRINTING
+#ifdef ENABLE_PRINT
 		  m_gpm (NULL),
 #endif
 		  m_bPreview (false), m_bPrinter (false){};
 	
-#ifndef WITHOUT_PRINTING
+#ifdef ENABLE_PRINT
 	GR_UnixAllocInfo(GnomePrintJob * gpm, bool bPreview)
 		: m_win(NULL), m_gpm (gpm), m_bPreview (bPreview), m_bPrinter (true){};
 #endif
@@ -124,13 +128,14 @@ public:
 	virtual bool isPrinterGraphics() const {return m_bPrinter;}
 
 	GdkWindow     * m_win;
-#ifndef WITHOUT_PRINTING
+#ifdef ENABLE_PRINT
 	GnomePrintJob * m_gpm;
 #endif
 	bool            m_bPreview;
 	bool            m_bPrinter;
 };
 
+
 class ABI_EXPORT GR_UnixPangoGraphics : public GR_Graphics
 {
 	friend class GR_UnixImage;
@@ -147,7 +152,7 @@ public:
 	static const char *    graphicsDescriptor(){return "Unix Pango";}
 	static GR_Graphics *   graphicsAllocator(GR_AllocInfo&);
 
-	virtual UT_sint32      measureUnRemappedChar(const UT_UCSChar c);
+	virtual UT_sint32      measureUnRemappedChar(const UT_UCSChar c, UT_uint32 * height = 0);
 	
 	virtual void		   drawChars(const UT_UCSChar* pChars,
 									 int iCharOffset, int iLength,
@@ -158,12 +163,12 @@ public:
 									 UT_sint32 xoff, UT_sint32 yoff);
 
 	virtual UT_uint32      measureString(const UT_UCSChar* s, int iOffset,
-										 int num,  UT_GrowBufElement* pWidths);
+										 int num,  UT_GrowBufElement* pWidths, UT_uint32 * height = 0);
 	
 	virtual GR_Font*	   getDefaultFont(UT_String& fontFamily,
 										  const char * pszLang);
 	
-	virtual void           setFont(GR_Font *);
+	virtual void           setFont(const GR_Font *);
 	virtual void           clearFont(void) {m_pPFont = NULL;} 
 
 	virtual void           setZoomPercentage(UT_uint32 iZoom);
@@ -209,9 +214,9 @@ public:
 	virtual UT_uint32 getFontDescent();
 	virtual UT_uint32 getFontHeight();
 
-	virtual UT_uint32 getFontAscent(GR_Font *);
-	virtual UT_uint32 getFontDescent(GR_Font *);
-	virtual UT_uint32 getFontHeight(GR_Font *);
+	virtual UT_uint32 getFontAscent(const GR_Font *);
+	virtual UT_uint32 getFontDescent(const GR_Font *);
+	virtual UT_uint32 getFontHeight(const GR_Font *);
 
 	virtual void		fillRect(GR_Color3D c,
 								 UT_sint32 x, UT_sint32 y,
@@ -302,8 +307,9 @@ public:
 	// all instances have to be created via GR_GraphicsFactory; see gr_Graphics.h
 	GR_UnixPangoGraphics(GdkWindow * win);
 	GR_UnixPangoGraphics();
-
 	inline bool _scriptBreak(GR_UnixPangoRenderInfo &ri);
+	virtual GdkDrawable * _getDrawable(void)
+	{  return static_cast<GdkDrawable *>(m_pWin);}
 
 	void _scaleCharacterMetrics(GR_UnixPangoRenderInfo & RI);
 	void _scaleJustification(GR_UnixPangoRenderInfo & RI);
@@ -375,8 +381,7 @@ private:
 	static int s_iMaxScript;
 };
 
-
-#ifndef WITHOUT_PRINTING
+#ifdef ENABLE_PRINT
 
 /*!
     When printing, we need to combine pango with GnomePrint;
@@ -468,9 +473,11 @@ class ABI_EXPORT GR_UnixPangoPrintGraphics : public GR_UnixPangoGraphics
 	virtual UT_uint32 getFontDescent();
 	virtual UT_uint32 getFontHeight();
 	
-	virtual UT_uint32 getFontAscent(GR_Font *);
-	virtual UT_uint32 getFontDescent(GR_Font *);
-	virtual UT_uint32 getFontHeight(GR_Font *);
+	virtual UT_uint32 getFontAscent(const GR_Font *);
+	virtual UT_uint32 getFontDescent(const GR_Font *);
+	virtual UT_uint32 getFontHeight(const GR_Font *);
+	virtual double    getResolutionRatio(void)
+	{ return _getResolutionRatio();}
 	GnomePrintContext * getGnomePrintContext(void) { return m_gpc;}
 
 	static GnomePrintConfig * s_setup_config (double mrgnTop,
@@ -480,6 +487,17 @@ class ABI_EXPORT GR_UnixPangoPrintGraphics : public GR_UnixPangoGraphics
 											  double width, double height,
 											  int copies, bool portrait);
 
+	static void s_setup_config (GnomePrintConfig *cfg,
+								double mrgnTop,
+								double mrgnBottom,
+								double mrgnLeft,
+								double mrgnRight,
+								double width, double height,
+								int copies, bool portrait);
+	
+	void   setPdfWorkaround(void)
+	{ m_bPdfLandscapeWorkaround = true;}
+
   protected:
 	double  _getResolutionRatio(void)
 	{
@@ -512,8 +530,8 @@ class ABI_EXPORT GR_UnixPangoPrintGraphics : public GR_UnixPangoGraphics
 	GnomePrintJob     *m_gpm;
 	GnomePrintContext *m_gpc;
 	double             m_width, m_height;
-	
+	bool              m_bPdfLandscapeWorkaround;
 };
-#endif // ifndef WHITOUT_PRINTING
+#endif // ifdef ENABLE_PRINT
 
 #endif
