@@ -23,11 +23,13 @@
 #define NOSERVICE
 #define NOIME
 #define NOMCX
+
 #include <windows.h>
 #include <winspool.h>
 
 #include "gr_Win32Graphics.h"
 #include "gr_Win32Image.h"
+#include "gr_Painter.h"
 #include <xap_Win32App.h>
 
 #include <xap_Win32Res_Cursors.rc2>
@@ -47,6 +49,8 @@
 #include <w32api.h>
 #endif
 
+UT_uint32 GR_Win32Graphics::s_iInstanceCount = 0;
+HDC GR_Win32Graphics::m_defPrintHDC = NULL;
 
 #define LOG_WIN32_EXCPT(msg)                                                  \
 {                                                                             \
@@ -159,7 +163,13 @@ GR_Win32Graphics::GR_Win32Graphics(HDC hdc, HWND hwnd)
 	m_hwnd = hwnd;
 
 	// init the print HDC with one for the default printer
-	m_printHDC = UT_GetDefaultPrinterDC();
+	
+	if (m_defPrintHDC == NULL) {
+		m_defPrintHDC = UT_GetDefaultPrinterDC();
+	}
+	
+	m_printHDC = m_defPrintHDC;
+	s_iInstanceCount++;
 
 	if(m_printHDC)
 	{
@@ -202,6 +212,7 @@ GR_Win32Graphics::~GR_Win32Graphics()
 {
 	_destroyFonts ();
 	UT_VECTOR_SPARSEPURGEALL( UT_Rect*, m_vSaveRect);
+	s_iInstanceCount--;
 		
 	/* Release saved bitmaps */
 	HBITMAP hBit;
@@ -225,9 +236,13 @@ GR_Win32Graphics::~GR_Win32Graphics()
 	delete m_pArPens;
 
 	DELETEP(m_pFontGUI);
-
-	if(m_printHDC)
+	
+	if(m_printHDC && m_printHDC != m_defPrintHDC)
 		DeleteDC(m_printHDC);
+	
+	if (s_iInstanceCount == 0)
+		DeleteDC(m_defPrintHDC);
+
 }
 
 bool GR_Win32Graphics::queryProperties(GR_Graphics::Properties gp) const
@@ -610,11 +625,11 @@ simple_exttextout:
 	}
 }
 
-void GR_Win32Graphics::setFont(GR_Font* pFont)
+void GR_Win32Graphics::setFont(const GR_Font* pFont)
 {
 	UT_ASSERT(pFont);	// TODO should we allow pFont == NULL?
 
-	GR_Win32Font* pWin32Font = static_cast<GR_Win32Font*>(pFont);
+	const GR_Win32Font* pWin32Font = static_cast<const GR_Win32Font*>(pFont);
 
 // TMN: This currently won't work since there is no way to tell
 // GR_Win32Graphics to "drop" a font. If a user of this class:
@@ -632,13 +647,13 @@ void GR_Win32Graphics::setFont(GR_Font* pFont)
 	if (m_pFont == NULL || pFont->getAllocNumber() != m_iFontAllocNo
 		|| pWin32Font->getPrimaryHDC() != m_hdc)
 	{
-		m_pFont = pWin32Font;
+		m_pFont = const_cast<GR_Win32Font*>(pWin32Font);
 		m_iFontAllocNo = pFont->getAllocNumber();
 		m_pFont->selectFontIntoDC(this, m_hdc);
 	}
 }
 
-UT_uint32 GR_Win32Graphics::getFontHeight(GR_Font * fnt)
+UT_uint32 GR_Win32Graphics::getFontHeight(const GR_Font * fnt)
 {
 	private_FontReverter janitor_(*this, m_pFont);
 
@@ -654,7 +669,7 @@ UT_uint32 GR_Win32Graphics::getFontHeight()
 	return (UT_uint32)(m_pFont->getHeight(m_hdc, m_printHDC));
 }
 
-UT_uint32 GR_Win32Graphics::getFontAscent(GR_Font* fnt)
+UT_uint32 GR_Win32Graphics::getFontAscent(const GR_Font* fnt)
 {
 	private_FontReverter janitor_(*this, m_pFont);
 
@@ -669,7 +684,7 @@ UT_uint32 GR_Win32Graphics::getFontAscent()
 	return (UT_uint32)(m_pFont->getAscent(m_hdc, m_printHDC));
 }
 
-UT_uint32 GR_Win32Graphics::getFontDescent(GR_Font* fnt)
+UT_uint32 GR_Win32Graphics::getFontDescent(const GR_Font* fnt)
 {
 	private_FontReverter janitor_(*this, m_pFont);
 
@@ -693,7 +708,7 @@ void GR_Win32Graphics::getCoverage(UT_NumberVector& coverage)
 	//UT_ASSERT(UT_TODO);
 }
 
-UT_sint32 GR_Win32Graphics::measureUnRemappedChar(const UT_UCSChar c)
+UT_sint32 GR_Win32Graphics::measureUnRemappedChar(const UT_UCSChar c, UT_uint32 * height)
 {
 	#ifdef GR_GRAPHICS_DEBUG
 	UT_DEBUGMSG(("GR_Win32Graphics::measureUnRemappedChar\n"));	
@@ -1013,7 +1028,7 @@ void GR_Win32Graphics::scroll(UT_sint32 dx, UT_sint32 dy)
 	{
 		return;
 	}
-	GR_CaretDisabler caretDisabler(getCaret());
+	GR_Painter caretDisablerPainter(this); // not an elegant way to disable all carets, but it works beautifully - MARCM
 
 	setExposePending(true);
 	ScrollWindowEx(m_hwnd, ddx, ddy, NULL, NULL, NULL, 0, SW_INVALIDATE);
@@ -1035,7 +1050,7 @@ void GR_Win32Graphics::scroll(UT_sint32 x_dest, UT_sint32 y_dest,
 	r.right = r.left + width;
 	r.bottom = r.top + height;
 	
-	GR_CaretDisabler caretDisabler(getCaret());
+	GR_Painter caretDisablerPainter(this); // not an elegant way to disable all carets, but it works beautifully - MARCM
 	
 	setExposePending(true);
 	ScrollWindowEx(m_hwnd, (x_dest - x_src), (y_dest - y_src),
@@ -1480,8 +1495,8 @@ GR_Win32Font::GR_Win32Font(LOGFONT & lf, double fPoints, HDC hdc, HDC printHDC)
 :	m_hdc(hdc),
 	m_xhdc(0), // once all the processing is done, this is changed to printHDC
 	m_yhdc(0), // once all the processing is done, this is changed to printHDC
-	m_layoutFont (0),
 	m_defaultCharWidth(0),
+	m_layoutFont (0),
 	m_tm(TEXTMETRIC()),
 	m_bGUIFont(false),
 	m_fPointSize(fPoints)
@@ -1923,7 +1938,7 @@ HFONT GR_Win32Font::getDisplayFont(GR_Graphics * pG)
 	return getFontFromCache(pixels, false, zoom);
 }
 
-UT_sint32 GR_Win32Font::measureUnRemappedChar(UT_UCSChar c)
+UT_sint32 GR_Win32Font::measureUnRemappedChar(UT_UCSChar c, UT_uint32 * height)
 {
 #ifndef ABI_GRAPHICS_PLUGIN_NO_WIDTHS
 	// first of all, handle 0-width spaces ...
@@ -2241,12 +2256,7 @@ GR_Image * GR_Win32Graphics::genImageFromRectangle(const UT_Rect & r) {
 	UT_sint32 x = (UT_sint32)((double)tdu(r.left) * m_fXYRatio);
 	UT_sint32 y = tdu(r.top);
 
-	if (!iWidth) { // can happen when drag'n'dropping text
-		iWidth = 1;
-	}
-	if (!iHeight) { // though not observed for height, safety never hurts
-		iHeight = 1;
-	}
+	UT_return_val_if_fail((iWidth > 0) && (iHeight > 0) && (y >= 0) && (x >= 0), NULL);
 
 	BITMAPINFO bmi; 
 	BYTE *imagedata;
