@@ -585,9 +585,9 @@ UT_uint32 GR_Win32USPGraphics::getFontDescent()
     being set and call SelectObject() from inside the functions that access the DC only if
     that is necessary.
 */
-void GR_Win32USPGraphics::setFont(GR_Font* pFont)
+void GR_Win32USPGraphics::setFont(const GR_Font* pFont)
 {
-	m_pFont = static_cast<GR_Win32Font *>(pFont);
+	m_pFont = const_cast<GR_Win32Font *>(static_cast<const GR_Win32Font *>(pFont));
 
 	UT_ASSERT_HARMLESS(pFont);	// TODO should we allow pFont == NULL?
 
@@ -1170,7 +1170,7 @@ void GR_Win32USPGraphics::prepareToRenderChars(GR_RenderInfo & ri)
 	UT_uint32 iZoom = getZoomPercentage();
 	GR_Win32USPFont * pFont = (GR_Win32USPFont*)RI.m_pFont;
 
-#ifdef DEBUG
+#if 0 //def DEBUG
 	UT_uint32 iPoints = (UT_uint32)pFont->getPointSize();
 #endif
 	
@@ -1367,7 +1367,7 @@ void GR_Win32USPGraphics::setPrintDC(HDC dc)
 		// since this is a printer DC we have to delete it once not needed
 		// the win32 graphics does not delete the printer dc, which is a bug in the pure
 		// win32 graphics class, but exactly what we need here.
-		if(m_printHDC)
+		if(m_printHDC && m_printHDC != m_defPrintHDC)
 			DeleteDC(m_printHDC);
 		
 		m_printHDC = dc;
@@ -1430,7 +1430,7 @@ void GR_Win32USPGraphics::measureRenderedCharWidths(GR_RenderInfo & ri)
 
 	UT_uint32 iZoom = getZoomPercentage();
 	
-#ifdef DEBUG
+#if 0 //def DEBUG
 	UT_uint32 iPoints = (UT_uint32)pFont->getPointSize();
 #endif
 
@@ -2392,7 +2392,7 @@ bool GR_Win32USPRenderInfo::append(GR_RenderInfo &ri, bool bReverse)
 
 bool GR_Win32USPRenderInfo::split (GR_RenderInfo *&pri, bool bReverse)
 {
-	UT_return_val_if_fail(m_pGraphics && m_pFont, false);
+	UT_return_val_if_fail(m_pGraphics && m_pFont && m_pItem, false);
 
 	UT_ASSERT_HARMLESS(!pri);
 	if(!pri)
