@@ -116,7 +116,7 @@ class ABI_EXPORT GR_Font
 	   provide different implementation
 	   NB: it is essential that this function is fast
 	*/
-	virtual bool doesGlyphExist(UT_UCS4Char g);
+	virtual bool doesGlyphExist(UT_UCS4Char g) const;
 //
 // UT_Rect of glyph in Logical units.
 // rec.left = bearing Left (distance from origin to start)
@@ -206,6 +206,8 @@ enum GR_GraphicsId
 	GRID_UNIX_PANGO      =  0x201,
 	GRID_WIN32_UNISCRIBE =  0x202,
 	GRID_UNIX_PANGO_PRINT = 0x203,
+	GRID_UNIX_PANGO_PIXMAP = 0x204,
+
 
 	GRID_LAST_EXTENSION = 0x0000ffff,
 
@@ -377,7 +379,7 @@ class ABI_EXPORT GR_Graphics
 	UT_sint32	ftlu(UT_sint32 fontUnits) const;
 	double		ftluD(double fontUnits) const;
 	
-	virtual void      setFont(GR_Font* pFont) = 0;
+	virtual void      setFont(const GR_Font* pFont) = 0;
     virtual void      clearFont(void) = 0;
 	virtual UT_uint32 getFontAscent() = 0;
 	virtual UT_uint32 getFontDescent() = 0;
@@ -387,17 +389,19 @@ class ABI_EXPORT GR_Graphics
 	virtual UT_uint32 measureString(const UT_UCSChar*s,
 									int iOffset,
 									int num,
-									UT_GrowBufElement* pWidths);
+									UT_GrowBufElement* pWidths, UT_uint32 *height = 0);
 
-	virtual UT_sint32 measureUnRemappedChar(const UT_UCSChar c) = 0;
+	virtual UT_sint32 measureUnRemappedChar(const UT_UCSChar c, UT_uint32 * height = 0) = 0;
 	virtual void getCoverage(UT_NumberVector& coverage) = 0;
 	
 	/* GR_Font versions of the above -- TODO: should I add drawChar* methods too? */
-	virtual UT_uint32 getFontAscent(GR_Font *)  = 0;
-	virtual UT_uint32 getFontDescent(GR_Font *) = 0;
-	virtual UT_uint32 getFontHeight(GR_Font *)  = 0;
+	virtual UT_uint32 getFontAscent(const GR_Font *)  = 0;
+	virtual UT_uint32 getFontDescent(const GR_Font *) = 0;
+	virtual UT_uint32 getFontHeight(const GR_Font *)  = 0;
+	virtual double    getResolutionRatio(void)
+	{return 1.0;}
 
-	UT_uint32         getMaxCharacterWidth(const UT_UCSChar*s, UT_uint32 Length);
+	void         getMaxCharacterDimension (const UT_UCSChar*s, UT_uint32 Length, UT_uint32 &width, UT_uint32 &height);
 
 	virtual void      setColor(const UT_RGBColor& clr) = 0;
 	virtual void      getColor(UT_RGBColor& clr) = 0;
