@@ -2,7 +2,7 @@
 
 /* AbiSource Application Framework
  * Copyright (C) 1998-2000 AbiSource, Inc.
- * Copyright (C) 2002 William Lachance 
+ * Copyright (C) 2002 William Lachance
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -19,12 +19,16 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
  * 02111-1307, USA.
  */
- 
+
   /*
-  * Port to Maemo Development Platform 
+  * Port to Maemo Development Platform
   * Author: INdT - Renato Araujo <renato.filho@indt.org.br>
   */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <gtk/gtk.h>
 #include <gdk/gdkx.h>
 #include <stdio.h>
@@ -35,7 +39,7 @@
 #include <vector>
 
 #include "ap_Features.h"
-
+#include "ut_string.h"
 #include "ut_types.h"
 #include "ut_assert.h"
 #include "ut_files.h"
@@ -53,23 +57,24 @@
 #include "ev_EditMethod.h"
 #include "xav_View.h"
 #include "fv_View.h"
+#include "fv_FrameEdit.h"
 #include "xad_Document.h"
 #include "gr_Graphics.h"
 #include "xap_UnixDialogHelper.h"
 #include "xap_UnixClipboard.h"
 #include "xap_Strings.h"
 #include "xap_Prefs.h"
-
-#include "fv_View.h"
+#include "ap_FrameData.h"
+#include "ev_Mouse.h"
 
 #include "ie_types.h"
 #include "ie_imp.h"
 #include "ie_impGraphic.h"
 #include "fg_Graphic.h"
 
-#ifdef HAVE_GNOMEVFS
-#include <libgnomevfs/gnome-vfs.h>
-#include <libgnomevfs/gnome-vfs-mime-utils.h>
+#ifdef WITH_GNOMEVFS
+  #include <libgnomevfs/gnome-vfs.h>
+  #include <libgnomevfs/gnome-vfs-mime-utils.h>
 #endif
 
 #ifdef HAVE_GCONF
@@ -90,8 +95,8 @@ enum {
 };
 
 static const GtkTargetEntry XAP_UnixFrameImpl__knownDragTypes[] = {
-	{"text/uri-list", 	0, TARGET_URI_LIST},
-	{"_NETSCAPE_URL", 	0, TARGET_URL}
+	{(gchar *)"text/uri-list", 	0, TARGET_URI_LIST},
+	{(gchar *)"_NETSCAPE_URL", 	0, TARGET_URL}
 };
 
 struct DragInfo {
@@ -100,7 +105,7 @@ struct DragInfo {
 
 	DragInfo()
 		: entries(NULL), count(0)
-	{		
+	{
 	}
 
 	~DragInfo()
@@ -155,7 +160,7 @@ static DragInfo * s_getDragInfo ()
 		dragInfo.addEntry((*iter).c_str(), 0, TARGET_DOCUMENT);
 		iter++;
 	}
-	
+
 	// image types
 	mimeTypes = IE_ImpGraphic::getSupportedMimeTypes();
 	iter = mimeTypes.begin();
@@ -178,11 +183,13 @@ static int s_mapMimeToUriType (const char * uri)
 	int target = TARGET_UNKNOWN;
 
 	gchar *mimeType;
-#ifdef HAVE_GNOMEVFS
+#ifdef WITH_GNOMEVFS
 	mimeType = gnome_vfs_get_mime_type (uri);
 #else
 	const gchar * suffix = UT_pathSuffix(uri);
 	if (suffix) {
+		if(suffix[0] == '.')
+			suffix++;
 		const gchar *mt = IE_Imp::getMimeTypeForSuffix(suffix);
 		if (!mt) {
 			mt = IE_ImpGraphic::getMimeTypeForSuffix(suffix);
@@ -207,13 +214,13 @@ static int s_mapMimeToUriType (const char * uri)
 			target = dragInfo->entries[i].info;
 			break;
 		}
-	
+
 	g_free (mimeType);
 	return target;
 }
 
 static void
-s_loadImage (const UT_UTF8String & file, XAP_Frame * pFrame, FV_View * pView)
+s_loadImage (const UT_UTF8String & file, XAP_Frame * pFrame, FV_View * pView,gint x, gint y)
 {
 	FG_Graphic    * pFG  = 0;
 	UT_Error error = IE_ImpGraphic::loadGraphic (file.utf8_str(), 0, &pFG);
@@ -222,13 +229,19 @@ s_loadImage (const UT_UTF8String & file, XAP_Frame * pFrame, FV_View * pView)
 			UT_DEBUGMSG(("Dom: could not import graphic (%s)\n", file.utf8_str()));
 			return;
 		}
+	UT_sint32 mouseX = x;
+	UT_sint32 mouseY = y;
+	if(pView && pView->getGraphics())
+		mouseX = pView->getGraphics()->tlu(x);
+	if(pView && pView->getGraphics())
+		mouseY = pView->getGraphics()->tlu(y);
 
-	pView->cmdInsertGraphic(pFG);
+	pView->cmdInsertPositionedGraphic(pFG,mouseX,mouseY);
 	DELETEP(pFG);
 }
 
 static void
-s_loadImage (UT_ByteBuf * bytes, XAP_Frame * pFrame, FV_View * pView)
+s_loadImage (UT_ByteBuf * bytes, XAP_Frame * pFrame, FV_View * pView, gint x, gint y)
 {
 	FG_Graphic    * pFG  = 0;
 	UT_Error error = IE_ImpGraphic::loadGraphic(bytes, 0, &pFG);
@@ -237,8 +250,14 @@ s_loadImage (UT_ByteBuf * bytes, XAP_Frame * pFrame, FV_View * pView)
 			UT_DEBUGMSG(("JK: could not import graphic from data buffer\n"));
 			return;
 		}
+	UT_sint32 mouseX = x;
+	UT_sint32 mouseY = y;
+	if(pView && pView->getGraphics())
+		mouseX = pView->getGraphics()->tlu(x);
+	if(pView && pView->getGraphics())
+		mouseY = pView->getGraphics()->tlu(y);
 
-	pView->cmdInsertGraphic(pFG);
+	pView->cmdInsertPositionedGraphic(pFG,mouseX,mouseY);
 	DELETEP(pFG);
 }
 
@@ -246,16 +265,17 @@ static void
 s_loadDocument (const UT_UTF8String & file, XAP_Frame * pFrame)
 {
 	XAP_Frame * pNewFrame = 0;
-	if (pFrame->isDirty() || pFrame->getFilename() || 
+	if (pFrame->isDirty() || pFrame->getFilename() ||
 		(pFrame->getViewNumber() > 0))
 		pNewFrame = XAP_App::getApp()->newFrame ();
 	else
 		pNewFrame = pFrame;
 
+
 	UT_Error error = pNewFrame->loadDocument(file.utf8_str(), 0 /* IEFT_Unknown */);
 	if (error)
 		{
-			// TODO: warn user that we couldn't open that file		 
+			// TODO: warn user that we couldn't open that file
 			// TODO: we crash if we just delete this without putting something
 			// TODO: in it, so let's go ahead and open an untitled document
 			// TODO: for now.
@@ -264,8 +284,40 @@ s_loadDocument (const UT_UTF8String & file, XAP_Frame * pFrame)
 		}
 }
 
+static void s_pasteFile(const UT_UTF8String & file, XAP_Frame * pFrame)
+{
+	    if(!pFrame)
+			return;
+	    XAP_App * pApp = XAP_App::getApp();
+	    PD_Document * newDoc = new PD_Document(pApp);
+	    UT_Error err = newDoc->readFromFile(file.utf8_str(), IEFT_Unknown);
+	    if ( err != UT_OK )
+		{
+			UNREFP(newDoc);
+			return;
+		}
+		FV_View * pView = static_cast<FV_View *>(pFrame->getCurrentView());
+		// we'll share the same graphics context, which won't matter because
+		// we only use it to get font metrics and stuff and not actually draw
+		GR_Graphics *pGraphics = pView->getGraphics();
+	    // create a new layout and view object for the doc
+	    FL_DocLayout *pDocLayout = new FL_DocLayout(newDoc,pGraphics);
+	    FV_View copyView(pApp,0,pDocLayout);
+
+	    pDocLayout->setView (&copyView);
+	    pDocLayout->fillLayouts();
+
+	    copyView.cmdSelect(0, 0, FV_DOCPOS_BOD, FV_DOCPOS_EOD); // select all the contents of the new doc
+	    copyView.cmdCopy(); // copy the contents of the new document
+	    pView->cmdPaste ( true ); // paste the contents into the existing document honoring the formatting
+
+	    DELETEP(pDocLayout);
+	    UNREFP(newDoc);
+	    return ;
+}
+
 static void
-s_loadUri (XAP_Frame * pFrame, const char * uri)
+s_loadUri (XAP_Frame * pFrame, const char * uri,gint x, gint y)
 {
 	FV_View * pView  = static_cast<FV_View*>(pFrame->getCurrentView ());
 
@@ -278,24 +330,38 @@ s_loadUri (XAP_Frame * pFrame, const char * uri)
 
 	if (type == TARGET_IMAGE)
 		{
-			s_loadImage (uri, pFrame, pView);
+			s_loadImage (uri, pFrame, pView,x,y);
 			return;
 		}
 	else
 		{
-			s_loadDocument (uri, pFrame);
-			return;
+			if(pFrame)
+			{
+				AP_FrameData *pFrameData = static_cast<AP_FrameData *>(pFrame->getFrameData());
+				if(pFrameData && pFrameData->m_bIsWidget)
+				{
+					s_pasteFile(uri,pFrame);
+				}
+				else if(pFrame->isDirty() || pFrame->getFilename())
+				{
+					s_pasteFile(uri,pFrame);
+				}
+				else
+				{
+					s_loadDocument (uri, pFrame);
+				}
+			}
 		}
 }
 
 static void
-s_loadUriList (XAP_Frame * pFrame, const char * uriList)
+s_loadUriList (XAP_Frame * pFrame, const char * uriList,gint x, gint y)
 {
 	gchar ** uris = g_uri_list_extract_uris(uriList);
 	gchar ** uriIter = uris;
 
 	while (uriIter && *uriIter) {
-		s_loadUri(pFrame, *uriIter);
+		s_loadUri(pFrame, *uriIter,x,y);
 		uriIter++;
 	}
 	g_strfreev(uris);
@@ -347,9 +413,66 @@ s_drag_data_get_cb (GtkWidget        *widget,
 	formatList[1] = 0;
 
 	XAP_UnixApp * pApp = static_cast<XAP_UnixApp *>(XAP_App::getApp ());
+	XAP_Frame * pFrame = pApp->getLastFocussedFrame();
+	if(!pFrame)
+		return;
+	FV_View * pView = static_cast<FV_View *>(pFrame->getCurrentView());
+	if(!pView)
+		return;
+	UT_DEBUGMSG(("UnixFrameImpl: s_drag_data_get_cb(%s)\n", targetName));
+	if(strcmp(targetName,"text/uri-list") == 0)
+	{
+		char * szName = *pApp->getTmpFile();
+		if(!szName)
+			return;
+		UT_sint32 iLen = strlen(szName);
+		UT_DEBUGMSG(("Gave name %s to Nautilus \n",szName));
+		gtk_selection_data_set (selection,
+								selection->target,
+								8,
+								(guchar *) szName,
+								iLen);
 
-	UT_DEBUGMSG(("DOM: s_drag_data_get_cb(%s)\n", targetName));
+		g_free(targetName);
+		return;
+	}
+	EV_EditMouseContext emc = pView->getLastMouseContext();
+	if(emc == EV_EMC_VISUALTEXTDRAG )
+	{
+		const UT_ByteBuf * pBuf = pView->getLocalBuf();
+		UT_DEBUGMSG(("pBuf %x \n",pBuf));
+		if(pBuf)
+			{
+				UT_DEBUGMSG((" data length %d \n", pBuf->getPointer(0)));
+			}
+		gtk_selection_data_set (selection,
+								selection->target,
+								8,
+								(guchar *) pBuf->getPointer(0),
+								pBuf->getLength());
+	}
+	if(emc == EV_EMC_IMAGE)
+	{
+		return;
+	}
+	if(emc == EV_EMC_POSOBJECT)
+	{
+		UT_DEBUGMSG(("Dragging positioned object \n"));
+		FV_FrameEdit * fvFrame  = pView->getFrameEdit();
+		const UT_ByteBuf * pBuf = NULL;
+		fvFrame->getPNGImage(&pBuf);
+		if(pBuf)
+		{
+			UT_DEBUGMSG(("Got data of length %d \n",pBuf->getLength()));
+				gtk_selection_data_set (selection,
+										selection->target,
+										8,
+										(guchar *) pBuf->getPointer(0),
+										pBuf->getLength());
 
+		}
+		return;
+	}
 	if (pApp->getCurrentSelection((const char **)formatList, &data, &dataLen, &formatFound))
 		{
 			UT_DEBUGMSG(("DOM: s_drag_data_get_cb SUCCESS!\n"));
@@ -363,11 +486,11 @@ s_drag_data_get_cb (GtkWidget        *widget,
 	g_free (targetName);
 }
 
-static void 
+static void
 s_dndDropEvent(GtkWidget        *widget,
 				 GdkDragContext   *context,
-				 gint              /*x*/,
-				 gint              /*y*/,
+				 gint              x,
+				 gint              y,
 				 GtkSelectionData *selection_data,
 				 guint             info,
 				 guint             /*time*/,
@@ -383,24 +506,24 @@ s_dndDropEvent(GtkWidget        *widget,
 	char *targetName = gdk_atom_name(selection_data->target);
 	UT_DEBUGMSG(("JK: target in selection = %s \n", targetName));
 
-	if (info == TARGET_URI_LIST) 
+	if (info == TARGET_URI_LIST)
 	{
 		const char * rawChar = reinterpret_cast<const char *>(selection_data->data);
 		UT_DEBUGMSG(("DOM: text in selection = %s \n", rawChar));
-		s_loadUriList (pFrame, rawChar);
-	} 
-	else if (info == TARGET_DOCUMENT) 
+		s_loadUriList (pFrame, rawChar,x,y);
+	}
+	else if (info == TARGET_DOCUMENT)
 	{
 		UT_DEBUGMSG(("JK: Document target as data buffer\n"));
 		s_pasteText (pFrame, targetName, selection_data->data, selection_data->length);
 	}
-	else if (info == TARGET_IMAGE) 
+	else if (info == TARGET_IMAGE)
 	{
 		UT_ByteBuf * bytes = new UT_ByteBuf( selection_data->length );
-	  
+
 		UT_DEBUGMSG(("JK: Image target\n"));
 		bytes->append (selection_data->data, selection_data->length);
-		s_loadImage (bytes, pFrame, pView);
+		s_loadImage (bytes, pFrame, pView,x,y);
 	}
 	else if (info == TARGET_URL)
 	{
@@ -413,11 +536,14 @@ s_dndDropEvent(GtkWidget        *widget,
 }
 
 static void
-s_dndRealDropEvent (GtkWidget *widget, GdkDragContext * context, 
+s_dndRealDropEvent (GtkWidget *widget, GdkDragContext * context,
 					   gint x, gint y, guint time, gpointer ppFrame)
 {
 	UT_DEBUGMSG(("DOM: dnd drop event\n"));
 	GdkAtom selection = gdk_drag_get_selection(context);
+
+	char *targetName = gdk_atom_name(selection);
+	UT_DEBUGMSG(("RealDrag and drop event: target in selection = %s \n", targetName));
 	gtk_drag_get_data (widget,context,selection,time);
 }
 
@@ -425,6 +551,8 @@ static void
 s_dndDragEnd (GtkWidget  *widget, GdkDragContext *context, gpointer ppFrame)
 {
 	UT_DEBUGMSG(("DOM: dnd end event\n"));
+
+//	XAP_UnixApp * pApp = static_cast<XAP_UnixApp *>(XAP_App::getApp ());
 }
 
 static void
@@ -454,7 +582,7 @@ void XAP_UnixFrameImpl::dragText()
 #endif
 }
 
-XAP_UnixFrameImpl::XAP_UnixFrameImpl(XAP_Frame *pFrame) : 
+XAP_UnixFrameImpl::XAP_UnixFrameImpl(XAP_Frame *pFrame) :
 	XAP_FrameImpl(pFrame),
 	m_imContext(NULL),
 	m_wTopLevelWindow(NULL),
@@ -468,12 +596,14 @@ XAP_UnixFrameImpl::XAP_UnixFrameImpl(XAP_Frame *pFrame) :
 	m_iZoomUpdateID(0),
 	m_iAbiRepaintID(0),
 	m_pUnixPopup(NULL),
-	m_dialogFactory(XAP_App::getApp(), pFrame)
+	m_dialogFactory(XAP_App::getApp(), pFrame),
+	m_iPreeditLen (0),
+	m_iPreeditStart (0)
 {
 }
 
-XAP_UnixFrameImpl::~XAP_UnixFrameImpl() 
-{ 	
+XAP_UnixFrameImpl::~XAP_UnixFrameImpl()
+{
 	if(m_bDoZoomUpdate) {
 		g_source_remove(m_iZoomUpdateID);
 	}
@@ -506,7 +636,7 @@ void XAP_UnixFrameImpl::_fe::sizeAllocate(GtkWidget * widget, GdkEvent * /*e*/,g
 
 gint XAP_UnixFrameImpl::_fe::focusIn(GtkWidget * widget, GdkEvent * /*e*/,gpointer /*data*/)
 {
-	return FALSE; 
+	return FALSE;
 }
 
 gint XAP_UnixFrameImpl::_fe::focusOut(GtkWidget * /* w*/, GdkEvent * /*e*/,gpointer /*data*/)
@@ -516,7 +646,6 @@ gint XAP_UnixFrameImpl::_fe::focusOut(GtkWidget * /* w*/, GdkEvent * /*e*/,gpoin
 
 void XAP_UnixFrameImpl::focusIMIn ()
 {
-	xxx_UT_DEBUGMSG(("oooooooooooooooooooooooo XAP_UnixFrameImpl::focusIMIn(), this 0x%x\n", this));
 	need_im_reset = true;
 	gtk_im_context_focus_in(getIMContext());
 	gtk_im_context_reset (getIMContext());
@@ -524,7 +653,6 @@ void XAP_UnixFrameImpl::focusIMIn ()
 
 void XAP_UnixFrameImpl::focusIMOut ()
 {
-	xxx_UT_DEBUGMSG(("oooooooooooooooooooooooo XAP_UnixFrameImpl::focusIMOut(), this 0x%x\n", this));
 	need_im_reset = true;
 	gtk_im_context_focus_out(getIMContext());
 }
@@ -542,8 +670,7 @@ gboolean XAP_UnixFrameImpl::_fe::focus_in_event(GtkWidget *w,GdkEvent */*event*/
 {
 	XAP_UnixFrameImpl * pFrameImpl = static_cast<XAP_UnixFrameImpl *>(g_object_get_data(G_OBJECT(w), "user_data"));
 	UT_return_val_if_fail(pFrameImpl,FALSE);
-	xxx_UT_DEBUGMSG(("\n===========================\nfocus_in_event: frame 0x%x\n=========================\n", pFrameImpl));
-	
+
 	XAP_Frame* pFrame = pFrameImpl->getFrame();
 	g_object_set_data(G_OBJECT(w), "toplevelWindowFocus",
 						GINT_TO_POINTER(TRUE));
@@ -555,26 +682,34 @@ gboolean XAP_UnixFrameImpl::_fe::focus_in_event(GtkWidget *w,GdkEvent */*event*/
 	//
 	// FIXME: Return TRUE because of a bug in gtk2. If you return FALSE (like
 	// you really should) you get a superfluous expose event which causes the
-	// the screen to flicker. Thanks the Bernhard Herzoff (of Sketch fame) 
-	// for giving the helpful clue here. 
+	// the screen to flicker. Thanks the Bernhard Herzoff (of Sketch fame)
+	// for giving the helpful clue here.
     //
 	// Try it again for gtk2.2 to see if this bug is still present.
 	//
-	return TRUE; 
+	return TRUE;
 }
 
 gboolean XAP_UnixFrameImpl::_fe::focus_out_event(GtkWidget *w,GdkEvent */*event*/,gpointer /*user_data*/)
 {
 	XAP_UnixFrameImpl * pFrameImpl = static_cast<XAP_UnixFrameImpl *>(g_object_get_data(G_OBJECT(w), "user_data"));
 	UT_return_val_if_fail(pFrameImpl,FALSE);
-	xxx_UT_DEBUGMSG(("\n===========================\nfocus_out_event: frame 0x%x\n=========================\n", pFrameImpl));
+
 	XAP_Frame* pFrame = pFrameImpl->getFrame();
 	g_object_set_data(G_OBJECT(w), "toplevelWindowFocus",
 						GINT_TO_POINTER(FALSE));
 	if (pFrame->getCurrentView())
 		pFrame->getCurrentView()->focusChange(AV_FOCUS_NONE);
 	pFrameImpl->focusIMOut();
-	return FALSE;
+	//
+	// FIXME: Return TRUE because of a bug in gtk2. If you return FALSE (like
+	// you really should) you get a superfluous expose event which causes the
+	// the screen to flicker. Thanks the Bernhard Herzoff (of Sketch fame)
+	// for giving the helpful clue here.
+    //
+	// Try it again for gtk2.2 to see if this bug is still present.
+	//
+	return TRUE;
 }
 
 gint XAP_UnixFrameImpl::_fe::button_press_event(GtkWidget * w, GdkEventButton * e)
@@ -584,7 +719,7 @@ gint XAP_UnixFrameImpl::_fe::button_press_event(GtkWidget * w, GdkEventButton *
 	pUnixFrameImpl->setTimeOfLastEvent(e->time);
 	AV_View * pView = pFrame->getCurrentView();
 	EV_UnixMouse * pUnixMouse = static_cast<EV_UnixMouse *>(pFrame->getMouse());
- 
+
 	gtk_grab_add(w);
 
 	pUnixFrameImpl->resetIMContext ();
@@ -600,7 +735,7 @@ gint XAP_UnixFrameImpl::_fe::button_press_event(GtkWidget * w, GdkEventButton *
 	{
 		XAP_UnixHildonApp * pThis =
 			static_cast<XAP_UnixHildonApp*>(XAP_App::getApp());
-		
+
 		UT_return_val_if_fail( pThis, FALSE );
 
 		UT_DEBUGMSG(("Hildon button_press_event: pThis 0x%x\n",
@@ -609,7 +744,7 @@ gint XAP_UnixFrameImpl::_fe::button_press_event(GtkWidget * w, GdkEventButton *
 		hildon_gtk_im_context_show(pThis->getIMContext());
 	}
 #endif
-	
+
 	if (pView)
 		pUnixMouse->mouseClick(pView,e);
 	return 1;
@@ -738,7 +873,7 @@ gint XAP_UnixFrameImpl::_fe::do_ZoomUpdate(gpointer /* XAP_UnixFrameImpl * */ p)
 
 		// don't need this for quickZoom
 #if 0
-		pUnixFrameImpl->_startViewAutoUpdater(); 
+		pUnixFrameImpl->_startViewAutoUpdater();
 #endif
 		pView->setWindowSize(iNewWidth, iNewHeight);
 		pFrame->quickZoom(); // was update zoom
@@ -799,7 +934,7 @@ gint XAP_UnixFrameImpl::_fe::configure_event(GtkWidget* w, GdkEventConfigure *e)
 
 		if(!pUnixFrameImpl->m_bDoZoomUpdate && (pUnixFrameImpl->m_iZoomUpdateID == 0))
 		{
-			pUnixFrameImpl->m_iZoomUpdateID = g_idle_add(static_cast<GSourceFunc>(do_ZoomUpdate), static_cast<gpointer>(pUnixFrameImpl));
+			pUnixFrameImpl->m_iZoomUpdateID = g_idle_add(reinterpret_cast<GSourceFunc>(do_ZoomUpdate), static_cast<gpointer>(pUnixFrameImpl));
 		}
 	}
 	return 1;
@@ -847,6 +982,7 @@ gint XAP_UnixFrameImpl::_fe::motion_notify_event(GtkWidget* w, GdkEventMotion* e
 
 gint XAP_UnixFrameImpl::_fe::scroll_notify_event(GtkWidget* w, GdkEventScroll* e)
 {
+	UT_DEBUGMSG(("Scroll event \n"));
 	XAP_UnixFrameImpl * pUnixFrameImpl = static_cast<XAP_UnixFrameImpl *>(g_object_get_data(G_OBJECT(w), "user_data"));
 	XAP_Frame* pFrame = pUnixFrameImpl->getFrame();
 	pUnixFrameImpl->setTimeOfLastEvent(e->time);
@@ -865,7 +1001,7 @@ gint XAP_UnixFrameImpl::_fe::key_release_event(GtkWidget* w, GdkEventKey* e)
 
 	// Let IM handle the event first.
 	if (gtk_im_context_filter_keypress(pUnixFrameImpl->getIMContext(), e)) {
-	    xxx_UT_DEBUGMSG(("IMCONTEXT keyevent swallow: %lu\n", e->keyval));
+	    UT_DEBUGMSG(("IMCONTEXT keyevent swallow: %lu\n", e->keyval));
 		pUnixFrameImpl->queueIMReset ();
 	    return 0;
 	}
@@ -886,8 +1022,8 @@ gint XAP_UnixFrameImpl::_fe::key_press_event(GtkWidget* w, GdkEventKey* e)
 			return 0;
 
 		// ... else, stop this signal
-		g_signal_stop_emission (G_OBJECT(w), 
-								g_signal_lookup ("key_press_event", 
+		g_signal_stop_emission (G_OBJECT(w),
+								g_signal_lookup ("key_press_event",
 												 G_OBJECT_TYPE (w)), 0);
 		return 1;
 	}
@@ -927,8 +1063,8 @@ gint XAP_UnixFrameImpl::_fe::key_press_event(GtkWidget* w, GdkEventKey* e)
 		return 0;
 
 	// ... else, stop this signal
-	g_signal_stop_emission (G_OBJECT(w), 
-							g_signal_lookup ("key_press_event", 
+	g_signal_stop_emission (G_OBJECT(w),
+							g_signal_lookup ("key_press_event",
 											 G_OBJECT_TYPE (w)), 0);
 	return 1;
 }
@@ -1001,7 +1137,7 @@ gint XAP_UnixFrameImpl::_fe::abi_expose_repaint(gpointer p)
 //
 // Grab our pointer so we can do useful stuff.
 //
-	xxx_UT_DEBUGMSG(("-----------------Doing Repaint----------------\n"));
+	UT_DEBUGMSG(("-----------------Doing Repaint----------------\n"));
 	UT_Rect localCopy;
 	XAP_UnixFrameImpl * pUnixFrameImpl = static_cast<XAP_UnixFrameImpl *>(p);
 	XAP_Frame* pFrame = pUnixFrameImpl->getFrame();
@@ -1042,14 +1178,44 @@ gint XAP_UnixFrameImpl::_fe::abi_expose_repaint(gpointer p)
 	return TRUE;
 }
 
+static bool bScrollWait = false;
+
+class _ViewScroll
+{
+public:
+	_ViewScroll(AV_View * pView, UT_sint32 amount):
+		m_pView(pView),m_amount(amount)
+	{
+	}
+	AV_View * m_pView;
+	UT_sint32 m_amount;
+};
+
+static gboolean _actualScroll(gpointer data)
+{
+	_ViewScroll * pVS = reinterpret_cast<_ViewScroll *>(data);
+	AV_View * pView = pVS->m_pView;
+	xxx_UT_DEBUGMSG(("vScrollSchanged callback\n"));
+	if (pView)
+		pView->sendVerticalScrollEvent(pVS->m_amount);
+	bScrollWait = false;
+	delete pVS;
+	return FALSE;
+}
+
 void XAP_UnixFrameImpl::_fe::vScrollChanged(GtkAdjustment * w, gpointer /*data*/)
 {
 	XAP_UnixFrameImpl * pUnixFrameImpl = static_cast<XAP_UnixFrameImpl *>(g_object_get_data(G_OBJECT(w), "user_data"));
+	if(bScrollWait)
+	{
+		xxx_UT_DEBUGMSG(("VScroll dropped!!! \n"));
+		return;
+	}
 	XAP_Frame* pFrame = pUnixFrameImpl->getFrame();
 	AV_View * pView = pFrame->getCurrentView();
-
-	if (pView)
-		pView->sendVerticalScrollEvent(static_cast<UT_sint32>(w->value));
+	_ViewScroll * pVS = new  _ViewScroll(pView,static_cast<UT_sint32>(w->value));
+	bScrollWait = true;
+	g_idle_add(_actualScroll, (gpointer) pVS);
 }
 
 void XAP_UnixFrameImpl::_fe::hScrollChanged(GtkAdjustment * w, gpointer /*data*/)
@@ -1238,7 +1404,7 @@ void XAP_UnixFrameImpl::_setCursor(GR_Graphics::Cursor c)
 
 	if (m_wStatusBar)
 		gdk_window_set_cursor(m_wStatusBar->window, cursor);
-	
+
 	gdk_cursor_unref(cursor);
 }
 
@@ -1274,6 +1440,11 @@ XAP_DialogFactory * XAP_UnixFrameImpl::_getDialogFactory(void)
 	return &m_dialogFactory;
 }
 
+GtkWidget *  XAP_UnixFrameImpl::_createInternalWindow (void)
+{
+	return gtk_window_new(GTK_WINDOW_TOPLEVEL);
+}
+
 // TODO: split me up into smaller pieces/subfunctions
 void XAP_UnixFrameImpl::_createTopLevelWindow(void)
 {
@@ -1297,31 +1468,31 @@ void XAP_UnixFrameImpl::_createTopLevelWindow(void)
 			g_error_free (err);
 		}
 	}
-	
+
 	bool bResult;
-	
+
 	if(m_iFrameMode == XAP_NormalFrame)
 	{
-		m_wTopLevelWindow = gtk_window_new(GTK_WINDOW_TOPLEVEL);
+		m_wTopLevelWindow = _createInternalWindow ();
 		gtk_window_set_title(GTK_WINDOW(m_wTopLevelWindow),
 				     XAP_App::getApp()->getApplicationTitleForTitleBar());
 		gtk_window_set_resizable(GTK_WINDOW(m_wTopLevelWindow), TRUE);
 		gtk_window_set_role(GTK_WINDOW(m_wTopLevelWindow), "topLevelWindow");
 		if ( wmIcon )
 			gtk_window_set_icon(GTK_WINDOW(m_wTopLevelWindow), wmIcon);
-		
+
 		gtk_window_set_resizable(GTK_WINDOW(m_wTopLevelWindow), TRUE);
-		gtk_window_set_role(GTK_WINDOW(m_wTopLevelWindow), "topLevelWindow");		
-		
+		gtk_window_set_role(GTK_WINDOW(m_wTopLevelWindow), "topLevelWindow");
+
 		g_object_set_data(G_OBJECT(m_wTopLevelWindow), "ic_attr", NULL);
-		g_object_set_data(G_OBJECT(m_wTopLevelWindow), "ic", NULL);		
-		
+		g_object_set_data(G_OBJECT(m_wTopLevelWindow), "ic", NULL);
+
 	}
 	g_object_set_data(G_OBJECT(m_wTopLevelWindow), "toplevelWindow",
 						m_wTopLevelWindow);
 	g_object_set_data(G_OBJECT(m_wTopLevelWindow), "toplevelWindowFocus",
 						GINT_TO_POINTER(FALSE));
-	g_object_set_data(G_OBJECT(m_wTopLevelWindow), "user_data", this); 
+	g_object_set_data(G_OBJECT(m_wTopLevelWindow), "user_data", this);
 
 	_setGeometry ();
 
@@ -1341,29 +1512,29 @@ void XAP_UnixFrameImpl::_createTopLevelWindow(void)
 
 	gtk_drag_dest_set (m_wTopLevelWindow,
 					   GTK_DEST_DEFAULT_ALL,
-					   dragInfo->entries, 
-					   dragInfo->count, 
+					   dragInfo->entries,
+					   dragInfo->count,
 					   GDK_ACTION_COPY);
 
 	gtk_drag_dest_add_text_targets (m_wTopLevelWindow);
 
-	g_signal_connect (G_OBJECT (m_wTopLevelWindow), 
+	g_signal_connect (G_OBJECT (m_wTopLevelWindow),
 					  "drag_data_received",
-					  G_CALLBACK (s_dndDropEvent), 
-					  static_cast<gpointer>(this));	
-  	g_signal_connect (G_OBJECT (m_wTopLevelWindow), 
-					  "drag_drop",
-					  G_CALLBACK (s_dndRealDropEvent), 
+					  G_CALLBACK (s_dndDropEvent),
 					  static_cast<gpointer>(this));
-	
-  	g_signal_connect (G_OBJECT (m_wTopLevelWindow), 
-					  "drag_end",
-					  G_CALLBACK (s_dndDragEnd), 
+  	g_signal_connect (G_OBJECT (m_wTopLevelWindow),
+					  "drag_drop",
+					  G_CALLBACK (s_dndRealDropEvent),
 					  static_cast<gpointer>(this));
 
-	g_signal_connect (G_OBJECT (m_wTopLevelWindow), 
+  	g_signal_connect (G_OBJECT (m_wTopLevelWindow),
+					  "drag_end",
+					  G_CALLBACK (s_dndDragEnd),
+					  static_cast<gpointer>(this));
+
+	g_signal_connect (G_OBJECT (m_wTopLevelWindow),
 					  "drag_begin",
-					  G_CALLBACK (s_dndDragBegin), 
+					  G_CALLBACK (s_dndDragBegin),
 					  static_cast<gpointer>(this));
 	g_signal_connect (G_OBJECT (m_wTopLevelWindow), "drag_data_get",
 					  G_CALLBACK (s_drag_data_get_cb), this);
@@ -1431,12 +1602,12 @@ void XAP_UnixFrameImpl::_createTopLevelWindow(void)
 	// so that it will appear outside of the scrollbars.
 	m_wStatusBar = NULL;
 
-#if !defined(EMBEDDED_TARGET) || defined(EMBEDDED_STATUSBAR)
+#ifdef ENABLE_STATUSBAR
 	if(m_iFrameMode == XAP_NormalFrame)
 		m_wStatusBar = _createStatusBarWindow();
 #endif
-	
-	if (m_wStatusBar) 
+
+	if (m_wStatusBar)
 	{
 		gtk_widget_show(m_wStatusBar);
 		gtk_box_pack_end(GTK_BOX(m_wVBox), m_wStatusBar, FALSE, FALSE, 0);
@@ -1451,48 +1622,113 @@ void XAP_UnixFrameImpl::_createTopLevelWindow(void)
 
 void XAP_UnixFrameImpl::_createIMContext(GdkWindow *w)
 {
-	xxx_UT_DEBUGMSG(("\n======================\nXAP_UnixFrameImp::_createIMContext(0x%x), this 0x%x\n====================\n",
-				 w, this));
-	
 	m_imContext = gtk_im_multicontext_new();
-	gtk_im_context_set_use_preedit (m_imContext, FALSE); // show alternate preedit stuff in a separate window or somesuch
+
+	gtk_im_context_set_use_preedit (m_imContext, FALSE);
+
 	gtk_im_context_set_client_window(m_imContext, w);
-	g_signal_connect(G_OBJECT(m_imContext), "commit", 
+
+	g_signal_connect(G_OBJECT(m_imContext), "commit",
 					 G_CALLBACK(_imCommit_cb), this);
+	g_signal_connect (m_imContext, "preedit_start",
+					  G_CALLBACK (_imPreeditStart_cb), this);
 	g_signal_connect (m_imContext, "preedit_changed",
 					  G_CALLBACK (_imPreeditChanged_cb), this);
+	g_signal_connect (m_imContext, "preedit_end",
+					  G_CALLBACK (_imPreeditEnd_cb), this);
 	g_signal_connect (m_imContext, "retrieve_surrounding",
 					  G_CALLBACK (_imRetrieveSurrounding_cb), this);
 	g_signal_connect (m_imContext, "delete_surrounding",
 					  G_CALLBACK (_imDeleteSurrounding_cb), this);
 }
 
-void XAP_UnixFrameImpl::_imPreeditChanged_cb (GtkIMContext *context, gpointer data)
+void XAP_UnixFrameImpl::_imPreeditStart_cb (GtkIMContext *context,
+											gpointer data)
 {
-	UT_DEBUGMSG(("Preedit Changed\n"));
+	XAP_UnixFrameImpl * pImpl = static_cast<XAP_UnixFrameImpl*>(data);
+	FV_View * pView =
+		static_cast<FV_View*>(pImpl->getFrame()->getCurrentView ());
 
-#if 0
-	gchar *preedit_string;
-	gint cursor_pos;
-	
-	gtk_im_context_get_preedit_string (context,
-									   &preedit_string, NULL,
-									   &cursor_pos);
-	entry->preedit_length = strlen (preedit_string);
-	cursor_pos = CLAMP (cursor_pos, 0, g_utf8_strlen (preedit_string, -1));
-	entry->preedit_cursor = cursor_pos;
-	g_free (preedit_string);
-	
-	gtk_entry_recompute (entry);
-#endif
+	pImpl->m_iPreeditStart = pView->getInsPoint ();
+	pImpl->m_iPreeditLen = 0;
+
+	UT_DEBUGMSG(("@@@@ Preedit Started, pos %d\n", pView->getInsPoint ()));
 }
 
-gint XAP_UnixFrameImpl::_imRetrieveSurrounding_cb (GtkIMContext *context, gpointer data)
+void XAP_UnixFrameImpl::_imPreeditEnd_cb (GtkIMContext *context,
+										  gpointer data)
 {
-	UT_DEBUGMSG(("Retrieve Surrounding\n"));
+	XAP_UnixFrameImpl * pImpl = static_cast<XAP_UnixFrameImpl*>(data);
+	FV_View * pView =
+		static_cast<FV_View*>(pImpl->getFrame()->getCurrentView ());
+
+	UT_DEBUGMSG(("@@@@ Preedit Ended\n"));
+
+	if (pImpl->m_iPreeditLen)
+		{
+			// Anything that might have been entered as part of pre-edit
+			// needs to be nuked.
+			UT_DEBUGMSG(("@@@@@ deleting preedit from %d, len %d\n",
+						 pImpl->m_iPreeditStart,
+						 pImpl->m_iPreeditLen));
+			pView->moveInsPtTo (pImpl->m_iPreeditStart);
+			pView->cmdCharDelete (true, pImpl->m_iPreeditLen);
+
+			pImpl->m_iPreeditLen = 0;
+		}
+
+	pImpl->m_iPreeditStart = 0;
+}
+
+void XAP_UnixFrameImpl::_imPreeditChanged_cb (GtkIMContext *context,
+											  gpointer data)
+{
+	gchar *text;
+	gint   len = 0;
+	gint   pos;
+	guint  insPt;
 
 	XAP_UnixFrameImpl * pImpl = static_cast<XAP_UnixFrameImpl*>(data);
-	FV_View * pView = static_cast<FV_View*>(pImpl->getFrame()->getCurrentView ());
+	XAP_Frame* pFrame = pImpl->getFrame();
+	FV_View * pView = static_cast<FV_View*>(pFrame->getCurrentView ());
+	ev_UnixKeyboard * pUnixKeyboard =
+		static_cast<ev_UnixKeyboard *>(pFrame->getKeyboard());
+
+	// delete previous pre-edit, if there is one
+	if (pImpl->m_iPreeditLen)
+		{
+			UT_DEBUGMSG(("deleting preedit from %d, len %d\n",
+						 pImpl->m_iPreeditStart,
+						 pImpl->m_iPreeditLen));
+			pView->moveInsPtTo (pImpl->m_iPreeditStart);
+			pView->cmdCharDelete (true, pImpl->m_iPreeditLen);
+
+			pImpl->m_iPreeditLen = 0;
+			pImpl->m_iPreeditStart = 0;
+		}
+
+	// fetch the updated pre-edit string.
+	gtk_im_context_get_preedit_string (context, &text, NULL, &pos);
+
+	if (!text || !(len = strlen (text)))
+		return;
+
+	pImpl->m_iPreeditStart = pView->getInsPoint ();
+	pImpl->m_iPreeditLen   = g_utf8_strlen (text, -1);
+
+	pUnixKeyboard->charDataEvent(pView, static_cast<EV_EditBits>(0),
+								 text, strlen(text));
+
+	UT_DEBUGMSG(("@@@@ Preedit Changed, text %s, len %d (utf8 chars %d)\n",
+				 text, len, pImpl->m_iPreeditLen));
+}
+
+gint XAP_UnixFrameImpl::_imRetrieveSurrounding_cb (GtkIMContext *context,
+												   gpointer data)
+{
+	XAP_UnixFrameImpl * pImpl = static_cast<XAP_UnixFrameImpl*>(data);
+	FV_View * pView =
+		static_cast<FV_View*>(pImpl->getFrame()->getCurrentView ());
 
 	PT_DocPosition begin_p, end_p, here;
 
@@ -1516,10 +1752,14 @@ gint XAP_UnixFrameImpl::_imRetrieveSurrounding_cb (GtkIMContext *context, gpoint
 	return TRUE;
 }
 
-gint XAP_UnixFrameImpl::_imDeleteSurrounding_cb (GtkIMContext *slave, gint offset, gint n_chars, gpointer data)
+gint XAP_UnixFrameImpl::_imDeleteSurrounding_cb (GtkIMContext *slave,
+												 gint offset, gint n_chars,
+												 gpointer data)
 {
+	xxx_UT_DEBUGMSG(("Delete Surrounding\n"));
 	XAP_UnixFrameImpl * pImpl = static_cast<XAP_UnixFrameImpl*>(data);
-	FV_View * pView = static_cast<FV_View*>(pImpl->getFrame()->getCurrentView ());
+	FV_View * pView =
+		static_cast<FV_View*>(pImpl->getFrame()->getCurrentView ());
 
 	PT_DocPosition insPt = pView->getInsPoint ();
 	if ((gint) insPt + offset < 0)
@@ -1532,7 +1772,8 @@ gint XAP_UnixFrameImpl::_imDeleteSurrounding_cb (GtkIMContext *slave, gint offse
 }
 
 // Actual keyboard commit should be done here.
-void XAP_UnixFrameImpl::_imCommit_cb(GtkIMContext *imc, const gchar *text, gpointer data)
+void XAP_UnixFrameImpl::_imCommit_cb(GtkIMContext *imc,
+									 const gchar *text, gpointer data)
 {
 	XAP_UnixFrameImpl * impl = static_cast<XAP_UnixFrameImpl*>(data);
 	impl->_imCommit (imc, text);
@@ -1541,14 +1782,28 @@ void XAP_UnixFrameImpl::_imCommit_cb(GtkIMContext *imc, const gchar *text, gpoin
 // Actual keyboard commit should be done here.
 void XAP_UnixFrameImpl::_imCommit(GtkIMContext *imc, const gchar * text)
 {
-	xxx_UT_DEBUGMSG(("\n<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<\nXAP_UnixFrameImpl::_imCommit(0x%x), this 0x%x\n<<<<<<<<<<<<<<<<<<\n",
-				 imc, this));
-				
 	XAP_Frame* pFrame = getFrame();
-	AV_View * pView   = pFrame->getCurrentView();
-	ev_UnixKeyboard * pUnixKeyboard = static_cast<ev_UnixKeyboard *>(pFrame->getKeyboard());
+	FV_View * pView = static_cast<FV_View*>(getFrame()->getCurrentView ());
+	ev_UnixKeyboard * pUnixKeyboard =
+		static_cast<ev_UnixKeyboard *>(pFrame->getKeyboard());
 
-	pUnixKeyboard->charDataEvent(pView, static_cast<EV_EditBits>(0), text, strlen(text));
+	if (m_iPreeditLen)
+		{
+			/* delete previous pre-edit */
+			UT_DEBUGMSG(("deleting preedit from %d, len %d\n",
+						 m_iPreeditStart,
+						 m_iPreeditLen));
+			pView->moveInsPtTo (m_iPreeditStart);
+			pView->cmdCharDelete (true, m_iPreeditLen);
+
+			m_iPreeditLen = 0;
+			m_iPreeditStart = 0;
+		}
+
+	pUnixKeyboard->charDataEvent(pView, static_cast<EV_EditBits>(0),
+								 text, strlen(text));
+
+	UT_DEBUGMSG(("<<<<<<<<_imCommit: text %s, len %d\n", text, strlen(text)));
 }
 
 GtkIMContext * XAP_UnixFrameImpl::getIMContext()
@@ -1567,7 +1822,7 @@ void XAP_UnixFrameImpl::_setGeometry ()
 	XAP_UnixApp * pApp = static_cast<XAP_UnixApp*>(XAP_App::getApp ());
 	pApp->getGeometry (&app_x, &app_y, &app_w, &app_h, &app_f);
 	// (ignore app_x, app_y & app_f since the WM will set them for us just fine)
-	  
+
 	// This is now done with --geometry parsing.
 	if (app_w == 0 || app_w > USHRT_MAX) app_w = 760;
         if (app_h == 0 || app_h > USHRT_MAX) app_h = 520;
@@ -1578,11 +1833,14 @@ void XAP_UnixFrameImpl::_setGeometry ()
 	// set geometry hints as the user requested
 	gint user_x = 0;
 	gint user_y = 0;
-	guint user_w = static_cast<guint>(app_w);
-	guint user_h = static_cast<guint>(app_h);
+	UT_uint32 uuser_w = static_cast<UT_uint32>(app_w);
+	UT_uint32 uuser_h = static_cast<UT_uint32>(app_h);
 	UT_uint32 user_f = 0;
 
-	pApp->getWinGeometry (&user_x, &user_y, &user_w, &user_h, &user_f);
+	pApp->getWinGeometry (&user_x, &user_y, &uuser_w, &uuser_h, &user_f);
+	// to avoid bad signedess warnings
+	gint user_w = static_cast<gint>(uuser_w);
+	gint user_h = static_cast<gint>(uuser_h);
 
 	UT_DEBUGMSG(("xap_UnixFrameImpl: user-width=%u, user-height=%u\n",
 				 static_cast<unsigned>(user_w),static_cast<unsigned>(user_h)));
@@ -1623,8 +1881,10 @@ void XAP_UnixFrameImpl::_setGeometry ()
 			user_h = static_cast<guint>(app_h);
 		}
 
-	if (user_w > USHRT_MAX) user_w = app_w;
-        if (user_h > USHRT_MAX) user_h = app_h;
+	if (user_w > USHRT_MAX)
+		user_w = app_w;
+        if (user_h > USHRT_MAX)
+		user_h = app_h;
 
 	if(getFrame()->getFrameMode() == XAP_NormalFrame)
 	{
@@ -1635,8 +1895,8 @@ void XAP_UnixFrameImpl::_setGeometry ()
 									   static_cast<GdkWindowHints>(GDK_HINT_MIN_SIZE));
 
 		GdkScreen *screen = gdk_screen_get_default ();
-		user_w = user_w < gdk_screen_get_width (screen) ? user_w : gdk_screen_get_width (screen);
-		user_h = user_h < gdk_screen_get_height (screen) ? user_h : gdk_screen_get_height (screen);
+		user_w = (user_w < gdk_screen_get_width (screen) ? user_w : gdk_screen_get_width (screen));
+		user_h = (user_h < gdk_screen_get_height (screen) ? user_h : gdk_screen_get_height (screen));
 		gtk_window_set_default_size (GTK_WINDOW(m_wTopLevelWindow), user_w, user_h);
 	}
 
@@ -1654,7 +1914,7 @@ void XAP_UnixFrameImpl::_setGeometry ()
 
 	// Remember geometry settings for next time
 	pApp->getPrefs()->setGeometry (user_x, user_y, user_w, user_h, user_f);
-			
+
 }
 
 /*!
@@ -1663,10 +1923,13 @@ void XAP_UnixFrameImpl::_setGeometry ()
  */
 void XAP_UnixFrameImpl::_rebuildMenus(void)
 {
+	// no menu? then nothing to rebuild!
+	if (!m_pUnixMenu) return;
+
 	// destroy old menu
 	m_pUnixMenu->destroy();
 	DELETEP(m_pUnixMenu);
-	
+
 	// build new one.
 	m_pUnixMenu = new EV_UnixMenuBar(static_cast<XAP_UnixApp*>(XAP_App::getApp()), getFrame(),
 					 m_szMenuLayoutName,
@@ -1717,7 +1980,7 @@ bool XAP_UnixFrameImpl::_raise()
 {
 	UT_ASSERT(m_wTopLevelWindow);
 	if (GTK_IS_WINDOW (m_wTopLevelWindow))
-		gtk_window_present(GTK_WINDOW (m_wTopLevelWindow));	
+		gtk_window_present(GTK_WINDOW (m_wTopLevelWindow));
 	return true;
 }
 
@@ -1760,32 +2023,33 @@ bool XAP_UnixFrameImpl::_runModalContextMenu(AV_View * /* pView */, const char *
 	// WL_REFACTOR: we DON'T want to do this
 	m_pUnixPopup = new EV_UnixMenuPopup(static_cast<XAP_UnixApp*>(XAP_App::getApp()),
 										pFrame, szMenuName, m_szMenuLabelSetName);
-	
+
 	if (m_pUnixPopup && m_pUnixPopup->synthesizeMenuPopup())
 	{
-		// Add our InputMethod selection item to the popup menu. Borrowed
+		// Add our InputMethod selection item to the popup menu, UNLESS WE'RE DOING A PRESENTATION Borrowed
 		// from gtkentry.c
-		GtkWidget * menuitem;
-		GtkWidget * submenu;
-		GtkWidget * menu = m_pUnixPopup->getMenuHandle();
+		if(!pFrame->isMenuScrollHidden())
+		{
+				GtkWidget * menuitem;
+				GtkWidget * submenu;
+				GtkWidget * menu = m_pUnixPopup->getMenuHandle();
+				menuitem = gtk_separator_menu_item_new ();
+				gtk_widget_show (menuitem);
+				gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
 
-		menuitem = gtk_separator_menu_item_new ();
-		gtk_widget_show (menuitem);
-		gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
+				const XAP_StringSet * pSS = XAP_App::getApp()->getStringSet();
 
-		const XAP_StringSet * pSS = XAP_App::getApp()->getStringSet();
+				menuitem = gtk_menu_item_new_with_label (pSS->getValue(XAP_STRING_ID_XIM_Methods));
 
-		menuitem = gtk_menu_item_new_with_label (pSS->getValue(XAP_STRING_ID_XIM_Methods));
+				gtk_widget_show (menuitem);
+				submenu = gtk_menu_new ();
+				gtk_menu_item_set_submenu (GTK_MENU_ITEM (menuitem), submenu);
 
-		gtk_widget_show (menuitem);
-		submenu = gtk_menu_new ();
-		gtk_menu_item_set_submenu (GTK_MENU_ITEM (menuitem), submenu);
-		
-		gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
-
-		gtk_im_multicontext_append_menuitems(GTK_IM_MULTICONTEXT(m_imContext), 
-											 GTK_MENU_SHELL(submenu));
+				gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
 
+				gtk_im_multicontext_append_menuitems(GTK_IM_MULTICONTEXT(m_imContext),
+													 GTK_MENU_SHELL(submenu));
+		}
 		// the popup will steal the mouse and so we won't get the
 		// button_release_event and we won't know to release our
 		// grab.  so let's do it here.  (when raised from a keyboard
@@ -1837,7 +2101,6 @@ EV_Menu* XAP_UnixFrameImpl::_getMainMenu()
 	return m_pUnixMenu;
 }
 
-
 void XAP_UnixFrameImpl::_setFullScreen(bool changeToFullScreen)
 {
 	if (!GTK_IS_WINDOW(m_wTopLevelWindow)) return;
