@@ -128,18 +128,8 @@ XAP_App::~XAP_App()
 
 	// run thru and destroy all frames on our window list.
 	UT_VECTOR_PURGEALL(XAP_Frame *, m_vecFrames);
-	//
-	// If the Embed plugins exist but aren't used the pointers
-	// are NULL. We used code instead of getting asserts
-	// for UT_VECTOR_PURGEALL
-	//
-	UT_sint32 i = 0;
-	for(i= 0; i<  m_vecEmbedManagers.getItemCount(); i++)
-	{
-	    GR_EmbedManager  * p = m_vecEmbedManagers.getNthItem(i);
-	    DELETEP(p);
-	}
-
+	// when can have NULL pointers....
+	UT_VECTOR_SPARSEPURGEALL(GR_EmbedManager  *, m_vecEmbedManagers);
 
 	FREEP(m_szAbiSuiteLibDir);
 	DELETEP(m_pEMC);
@@ -320,20 +310,6 @@ bool XAP_App::initialize(const char * szKeyBindingsKey, const char * szKeyBindin
 	// init keyboard language (cannot be in the constructor as it
 	// requires the platform code already initialised
 	setKbdLanguage(_getKbdLanguage());
-	
-#if 0 
-	m_pEMC = AP_GetEditMethods();
-	UT_ASSERT(m_pEMC);
-
-	m_pBindingSet = new AP_BindingSet(m_pEMC);
-	UT_ASSERT(m_pBindingSet);
-	
-	m_pMenuActionSet = AP_CreateMenuActionSet();
-	UT_ASSERT(m_pMenuActionSet);
-
-	m_pToolbarActionSet = AP_CreateToolbarActionSet();
-	UT_ASSERT(m_pToolbarActionSet);
-#endif
 
 	// HACK: for now, this works from XAP code
 	// TODO: where should this really go?
@@ -697,11 +673,7 @@ bool XAP_App::rememberFrame(XAP_Frame * pFrame, XAP_Frame * pCloneOf)
 		for (UT_uint32 j=0; j<pvClones->getItemCount(); j++)
 		{
 			XAP_Frame * f = pvClones->getNthItem(j);
-			if(!f)
-			{
-				UT_ASSERT_HARMLESS(f);
-				continue;
-			}
+			UT_continue_if_fail(f);
 
 			f->setViewNumber(j+1);
 
@@ -772,11 +744,7 @@ bool XAP_App::forgetFrame(XAP_Frame * pFrame)
 				for (UT_uint32 j=0; j<count; j++)
 				{
 					f = static_cast<XAP_Frame *>(pvClones->getNthItem(j));
-					if(!f)
-					{
-						UT_ASSERT_HARMLESS(f);
-						continue;
-					}
+					UT_continue_if_fail(f);
 
 					f->setViewNumber(j+1);
 					f->updateTitle();
@@ -858,11 +826,7 @@ bool XAP_App::updateClones(XAP_Frame * pFrame)
 		for (UT_uint32 j=0; j<count; j++)
 		{
 			f = pvClones->getNthItem(j);
-			if(!f)
-			{
-				UT_ASSERT_HARMLESS(f);
-				continue;
-			}
+			UT_continue_if_fail(f);
 
 			f->updateTitle();
 		}
@@ -906,11 +870,7 @@ UT_sint32 XAP_App::findFrame(const char * szFilename)
 	for (UT_uint32 i=0; i<getFrameCount(); i++)
 	{
 		XAP_Frame * f = getFrame(i);
-		if(!f)
-		{
-			UT_ASSERT_HARMLESS(f);
-			continue;
-		}
+		UT_continue_if_fail(f);
 		const char * s = f->getFilename();
 
 		if (s && *s && (0 == g_ascii_strcasecmp(szFilename, s)))
@@ -1369,14 +1329,16 @@ EV_EditEventMapper * XAP_App::getEditEventMapper(void) const
 	return m_pInputModes->getCurrentMap();
 }
 
-UT_sint32 XAP_App::setInputMode(const char * szName)
+UT_sint32 XAP_App::setInputMode(const char * szName, bool bForce)
 {
 	UT_uint32 i;
 	
+	UT_DEBUGMSG(("XAP_App::setInputMode: %s %d\n", szName, bForce));
+	
 	UT_return_val_if_fail(m_pInputModes,-1);
 	const char * szCurrentName = m_pInputModes->getCurrentMapName();
-	if (g_ascii_strcasecmp(szName,szCurrentName) == 0)
-		return -1;					// already set, no change required
+	if (!bForce && (g_ascii_strcasecmp(szName,szCurrentName) == 0))
+		return 0;					// already set, no change required
 
 	EV_EditEventMapper * p = m_pInputModes->getMapByName(szName);
 	if (!p)
@@ -1384,10 +1346,10 @@ UT_sint32 XAP_App::setInputMode(const char * szName)
 		// map not previously loaded -- we need to install it first
 
 		EV_EditBindingMap * pBindingMap = m_pApp->getBindingMap(szName);
-		UT_ASSERT(pBindingMap);
+		UT_return_val_if_fail(pBindingMap,-1);
 		bool bResult;
 		bResult = m_pInputModes->createInputMode(szName,pBindingMap);
-		UT_ASSERT(bResult);
+		UT_return_val_if_fail(bResult,-1);
 	}
 	
 	// note: derrived classes will need to update keyboard
@@ -1402,6 +1364,10 @@ UT_sint32 XAP_App::setInputMode(const char * szName)
 		getFrame(i)->getCurrentView()->notifyListeners(AV_CHG_INPUTMODE);
 	}
 	
+	// rebuild menu's
+	UT_DEBUGMSG(("XAP_App::setInputMode:: rebuilding menu's!"));
+	rebuildMenus();
+	
 	return (bStatus);
 }
 
