@@ -1272,7 +1272,7 @@ void fl_TableLayout::_lookupProperties(const PP_AttrProp* pSectionAP)
 		GR_Graphics * pG = getDocLayout()->getGraphics();
 		UT_return_if_fail( pView && pG );
 		
-		if(pView->getViewMode() == VIEW_NORMAL && m_iLeftColPos < 0 &&
+		if((pView->getViewMode() == VIEW_NORMAL) || (pView->getViewMode() == VIEW_WEB) && m_iLeftColPos < 0 &&
 		   !pG->queryProperties(GR_Graphics::DGP_PAPER))
 		{
 			m_iLeftColPos = 0;
@@ -1592,7 +1592,7 @@ void fl_TableLayout::_lookupMarginProperties(const PP_AttrProp* pSectionAP)
 		GR_Graphics * pG = getDocLayout()->getGraphics();
 		UT_return_if_fail( pView && pG );
 
-		if(pView->getViewMode() == VIEW_NORMAL && m_iLeftColPos < 0 &&
+		if((pView->getViewMode() == VIEW_NORMAL) || (pView->getViewMode() == VIEW_WEB) && m_iLeftColPos < 0 &&
 		   !pG->queryProperties(GR_Graphics::DGP_PAPER))
 		{
 			m_iLeftColPos = 0;
@@ -1945,7 +1945,7 @@ void fl_CellLayout::setCellContainerProperties(fp_CellContainer * pCell)
 			{
 				UT_sint32 iImageWidth;
 				UT_sint32 iImageHeight;
-				UT_ByteBuf * pBB = static_cast<FG_GraphicRaster *>(m_pGraphicImage)->getRaster_PNG();
+				const UT_ByteBuf * pBB = static_cast<FG_GraphicRaster *>(m_pGraphicImage)->getRaster_PNG();
 				UT_PNG_getDimensions(pBB, iImageWidth, iImageHeight);
 				iWidth = pG->tlu(iImageWidth);
 				iHeight = pG->tlu(iImageHeight);
