@@ -19,6 +19,10 @@
  * 02111-1307, USA.
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <stdlib.h>
 #include <string.h>
 #include <time.h>
@@ -37,7 +41,7 @@
 #include "fv_View.h"
 #include "fb_Alignment.h"
 #include "fl_TableLayout.h"
-
+#include "xap_Frame.h"
 #include "ut_debugmsg.h"
 #include "ut_assert.h"
 #include "ut_string.h"
@@ -63,7 +67,7 @@ fp_TextRun::fp_TextRun(fl_BlockLayout* pBL,
 					   bool bLookupProperties)
 :	fp_Run(pBL,iOffsetFirst, iLen, FPRUN_TEXT),
 	m_fPosition(TEXT_POSITION_NORMAL),
-#ifndef WITHOUT_SPELL
+#ifdef ENABLE_SPELL
 	m_bSpellSquiggled(false),
 	m_bGrammarSquiggled(false),
 #endif
@@ -222,13 +226,12 @@ void fp_TextRun::_lookupProperties(const PP_AttrProp * pSpanAP,
 
 	bChanged |= (oldPos != m_fPosition);
 
-	GR_Font * pFont;
-
-	pFont = const_cast<GR_Font *>(pLayout->findFont(pSpanAP,pBlockAP,pSectionAP,pG));
+	const GR_Font * pFont = pLayout->findFont(pSpanAP,pBlockAP,pSectionAP,pG);
 	xxx_UT_DEBUGMSG(("Old font %x new font %x \n",_getFont(),pFont));
 	if (_getFont() != pFont)
 	{
 		_setFont(pFont);
+		pG->setFont(_getFont());
 		_setAscent(pG->getFontAscent(pFont));
 		_setDescent(pG->getFontDescent(pFont));
 		_setHeight(pG->getFontHeight(pFont));
@@ -250,9 +253,10 @@ void fp_TextRun::_lookupProperties(const PP_AttrProp * pSpanAP,
 			bChanged = true;
 		}
 	}
-
-	pG->setFont(_getFont());
-
+	else
+	{
+		pG->setFont(_getFont());
+	}
 	//set the language member
 	UT_Language lls;
 	const gchar * pszLanguage = PP_evalProperty("lang",pSpanAP,pBlockAP,pSectionAP, pDoc, true);
@@ -265,7 +269,7 @@ void fp_TextRun::_lookupProperties(const PP_AttrProp * pSpanAP,
 	xxx_UT_DEBUGMSG(("!!!!!!!! Language of run set to %s pointer %x run %x \n",getLanguage(),m_pLanguage,this));
 	if(pszOldLanguage && (m_pLanguage != pszOldLanguage))
 	{
-#ifndef WITHOUT_SPELL
+#ifdef ENABLE_SPELL
 	        UT_uint32 reason =  0;
 		if( getBlock()->getDocLayout()->getAutoSpellCheck())
 		{
@@ -1146,7 +1150,7 @@ void fp_TextRun::mergeWithNext(void)
 			// is not going to change
 		}
 	}
-
+	setMustClearScreen();
 
 	delete pNext;
 }
@@ -1246,7 +1250,10 @@ bool fp_TextRun::split(UT_uint32 iSplitOffset)
 		// the split function created a copy of GR_Item in the render
 		// info; bring the member into sync with it (m_pItem is where the GR_Item lives and where it
 		// is destroyed)
-		pNew->m_pItem = const_cast<GR_Item *>(pNew->m_pRenderInfo->m_pItem);
+		if(pNew->m_pRenderInfo)
+		{
+			pNew->m_pItem = pNew->m_pRenderInfo->m_pItem;
+		}
 	}
 	else
 	{
@@ -1413,16 +1420,25 @@ void fp_TextRun::_clearScreen(bool /* bFullLineHeightRect */)
 //	UT_ASSERT(!isDirty());
 	UT_ASSERT(getGraphics()->queryProperties(GR_Graphics::DGP_SCREEN));
 	UT_sint32 iExtra = 0;
+	if(getWidth() == 0)
+	{
+		//
+		// Can't clear if the width is 0
+		//
+		return;
+	}
 	if(!getLine()->isEmpty() && getLine()->getLastVisRun() == this)   //#TF must be last visual run
 	{
 		// Last run on the line so clear to end.
 		if(isSelectionDraw())
 		{
-			UT_Rect * pRect = const_cast<UT_Rect *>(getGraphics()->getClipRect());
+			const UT_Rect *pRect = getGraphics()->getClipRect();
 			if(pRect)
 			{
-				pRect->width += getGraphics()->tlu(5); // uwog will hate me..
-				iExtra += getGraphics()->tlu(5); // But I just want it to work
+				UT_Rect r = *pRect;
+				r.width += getGraphics()->tlu(5); 
+				iExtra += getGraphics()->tlu(5); 
+				getGraphics()->setClipRect(&r);
 			}
 		}
 		else
@@ -1463,12 +1479,13 @@ void fp_TextRun::_clearScreen(bool /* bFullLineHeightRect */)
 	fp_Line * thisLine = getLine();
 	fp_Run * pPrev = getPrevRun();
 	fp_Run * pNext = getNextRun();
-	UT_sint32 leftClear = getAscent()/2;
+	//	UT_sint32 leftClear = getAscent()/2;
+   	UT_sint32 leftClear = getDescent();
 	if(isSelectionDraw())
 	{
 		leftClear = 0;
 	}
-	UT_sint32 rightClear = getAscent()/2 + iExtra;
+	UT_sint32 rightClear = getDescent() + iExtra;
 
 	UT_sint32 iCumWidth = leftClear;
 	if(thisLine != NULL)
@@ -1507,8 +1524,8 @@ void fp_TextRun::_clearScreen(bool /* bFullLineHeightRect */)
 	}
 	Fill(getGraphics(),xoff - leftClear, yoff, getWidth() + leftClear + rightClear,
 		 getLine()->getHeight());
-	xxx_UT_DEBUGMSG(("leftClear = %d width = %d xoff %d height %d \n",
-					 leftClear,getWidth(),xoff,getLine()->getHeight()));
+	xxx_UT_DEBUGMSG(("leftClear = %d total width = %d xoff %d height %d \n",
+					 leftClear,getWidth()+leftClear+rightClear,xoff,getLine()->getHeight()));
 
 }
 const gchar * fp_TextRun::getLanguage() const
@@ -1553,7 +1570,8 @@ void fp_TextRun::_draw(dg_DrawArgs* pDA)
 	UT_sint32 yTopOfRun = pDA->yoff - getAscent() - pG->tlu(1); // Hack to remove
 	UT_sint32 yTopOfSel = yTopOfRun + pG->tlu(1); // final character dirt
 #else
-	UT_sint32 yTopOfRun = pDA->yoff - getAscent();
+  	UT_sint32 yTopOfRun = pDA->yoff - getAscent();
+	//	UT_sint32 yTopOfRun = pDA->yoff - pG->getFontAscent(_getFont());
 	UT_sint32 yTopOfSel = yTopOfRun;
 #endif
 	xxx_UT_DEBUGMSG(("_draw Text: yoff %d \n",pDA->yoff));
@@ -1912,12 +1930,13 @@ void fp_TextRun::_draw(dg_DrawArgs* pDA)
 		m_pRenderInfo->m_iLength = iSegmentOffset[iSegment+1]-iSegmentOffset[iSegment];
 		m_pRenderInfo->m_xoff = iX;
 		m_pRenderInfo->m_yoff = yTopOfRun;
+		xxx_UT_DEBUGMSG((" _drawText yTopOfRun %d \n",yTopOfRun));
 		xxx_UT_DEBUGMSG(("_drawText segment %d off %d length %d width %d \n",iSegment,iMyOffset,m_pRenderInfo->m_iLength ,iSegmentWidth[iSegment]));
 		painter.renderChars(*m_pRenderInfo);
 		
 #if 0 
 		//DEBUG
-		GR_Font * f = _getFont();
+		const GR_Font * f = _getFont();
 		UT_uint32 _ascent, _descent, _height;
 		
 		_ascent = pG->getFontAscent(f);
@@ -1943,7 +1962,7 @@ void fp_TextRun::_draw(dg_DrawArgs* pDA)
 		_drawInvisibles(pDA->xoff, yTopOfRun);
 	}
 
-#ifndef WITHOUT_SPELL
+#ifdef ENABLE_SPELL
 	// TODO: draw this underneath (ie, before) the text and decorations
 	if(pG->queryProperties(GR_Graphics::DGP_SCREEN))
 	{
@@ -2143,7 +2162,7 @@ void fp_TextRun::_drawLastChar(bool bSelection)
 	
 	if(!getLength())
 		return;
-	return;
+	//	return;
 	// have to set font (and colour!), since we were called from a run
 	// using different font
 	GR_Graphics * pG = getGraphics();
@@ -2244,7 +2263,7 @@ void fp_TextRun::_drawFirstChar(bool bSelection)
 	
 	pG->prepareToRenderChars(*m_pRenderInfo);
 	painter.renderChars(*m_pRenderInfo);
-#ifndef WITHOUT_SPELL
+#ifdef ENABLE_SPELL
 	if(pG->queryProperties(GR_Graphics::DGP_SCREEN))
 	{
 		m_bSpellSquiggled = false;
@@ -2309,9 +2328,17 @@ void fp_TextRun::_drawInvisibles(UT_sint32 xoff, UT_sint32 yoff)
 	_drawInvisibleSpaces(xoff,yoff);
 }
 
-#ifndef WITHOUT_SPELL
+#ifdef ENABLE_SPELL
 void fp_TextRun::_drawSquiggle(UT_sint32 top, UT_sint32 left, UT_sint32 right, FL_SQUIGGLE_TYPE iSquiggle)
 {
+	if(_getView())
+	{
+			XAP_Frame * pFrame =  static_cast<XAP_Frame*>(_getView()->getParentData());
+			if(pFrame && pFrame->isMenuScrollHidden())
+			{
+					return;
+			}
+	}
 	if (!(getGraphics()->queryProperties(GR_Graphics::DGP_SCREEN)))
 	{
 		return;
