@@ -221,11 +221,6 @@ void AP_Win32Dialog_Options::_controlEnable( tControl id, bool value )
 			EnableWindow(GetDlgItem((HWND)getPage(PG_GENERAL),AP_RID_DIALOG_OPTIONS_CHK_AutoLoadPlugins),value);
 			return;
 
-		case id_SHOWSPLASH:
-			EnableWindow(GetDlgItem((HWND)getPage(PG_GENERAL),AP_RID_DIALOG_OPTIONS_CHK_ShowSplash),value);
-			return;
-
-
 
 		case id_CHECK_AUTO_SAVE_FILE:
 			EnableWindow(GetDlgItem((HWND)getPage(PG_DOCUMENT),AP_RID_DIALOG_OPTIONS_CHK_AutoSaveFile),value);
@@ -299,7 +294,6 @@ void	AP_Win32Dialog_Options::_set##Bool(bool b) { \
 
 DEFINE_GET_SET_BOOL(PG_GENERAL,ViewCursorBlink)
 DEFINE_GET_SET_BOOL(PG_GENERAL,LanguageWithKeyboard)
-DEFINE_GET_SET_BOOL(PG_GENERAL,ShowSplash)
 DEFINE_GET_SET_BOOL(PG_GENERAL,AllowCustomToolbars)
 DEFINE_GET_SET_BOOL(PG_GENERAL,AutoLoadPlugins)
 
@@ -423,7 +417,7 @@ void AP_Win32Dialog_Options::_gatherUILanguage(UT_String &stRetVal)
 		stRetVal = pLang;
 	}				
 	else
-		stRetVal.clear();
+		stRetVal = m_curLang;
 }
 
 void AP_Win32Dialog_Options::_setUILanguage(const UT_String &stExt)
@@ -621,9 +615,7 @@ AP_Win32Dialog_Options_General::~AP_Win32Dialog_Options_General()
 */	
 void AP_Win32Dialog_Options_General::_onCommand(HWND hWnd, WPARAM wParam, LPARAM lParam)
 {
-	WORD wNotifyCode = HIWORD(wParam);
 	WORD wId = LOWORD(wParam);
-	HWND hWndCtrl = (HWND)lParam;	
 	AP_Win32Dialog_Options*	 pParent=  (AP_Win32Dialog_Options*)getContainer();	
 	AP_Dialog_Background *pColorDialog;
 	UT_RGBColor rgbColor;
@@ -670,7 +662,6 @@ void AP_Win32Dialog_Options_General::_onInitDialog()
 	_DS2(OPTIONS_LBL_UNITS,					DLG_Options_Label_ViewUnits);	
 	_DS2(OPTIONS_BTN_BGColor,				DLG_Options_Label_ChooseForTransparent);
 	_DS2(OPTIONS_CHK_AllowCustomToolbars,	DLG_Options_Label_CheckAllowCustomToolbars);
-	_DS2(OPTIONS_CHK_ShowSplash, 			DLG_Options_Label_ShowSplash);
 	_DS2(OPTIONS_CHK_AutoLoadPlugins,		DLG_Options_Label_CheckAutoLoadPlugins);
 	_DS2(OPTIONS_STATIC_UI,					DLG_Options_Label_UI);
 	_DS2(OPTIONS_STATIC_APPSTARTUP,			DLG_Options_Label_AppStartup);
@@ -762,7 +753,6 @@ AP_Win32Dialog_Options_Document::~AP_Win32Dialog_Options_Document()
 */	
 void AP_Win32Dialog_Options_Document::_onCommand(HWND hWnd, WPARAM wParam, LPARAM lParam)
 {
-	WORD wNotifyCode = HIWORD(wParam);
 	WORD wId = LOWORD(wParam);	
 	AP_Win32Dialog_Options*	 pParent=  (AP_Win32Dialog_Options*)getContainer();	
 	BOOL bChecked;	
@@ -777,10 +767,6 @@ void AP_Win32Dialog_Options_Document::_onCommand(HWND hWnd, WPARAM wParam, LPARA
 			EnableWindow( GetDlgItem( hWnd, AP_RID_DIALOG_OPTIONS_TXT_AutoSaveExtension), bChecked );
 		return;
 
-	case AP_RID_DIALOG_OPTIONS_CHK_ShowSplash:			
-		pParent->_enableDisableLogic(AP_Dialog_Options::id_SHOWSPLASH); 	
-		return;	
-	
 	case AP_RID_DIALOG_OPTIONS_CHK_LanguageWithKeyboard:  pParent->_enableDisableLogic(AP_Dialog_Options::id_CHECK_LANG_WITH_KEYBOARD);return;
 
 		
@@ -833,7 +819,6 @@ void AP_Win32Dialog_Options_Document::_onInitDialog()
 bool AP_Win32Dialog_Options_Document::isAutoSaveInRange()
 {
 	int iValue = GetDlgItemInt(getHandle(), AP_RID_DIALOG_OPTIONS_TXT_AutoSavePeriod, NULL, FALSE);
-	AP_Win32Dialog_Options*	 pParent=  (AP_Win32Dialog_Options*)getContainer();		
 	char szTemp[10];
 	snprintf( szTemp, 10, "%d", iValue);	
 	
