@@ -411,8 +411,6 @@ dcl(DLG_Options_Label_WithExtension,		"With extension:")
 dcl(DLG_Options_Label_PrefsAutoSave,	"&Automatically save this Scheme")
 dcl(DLG_Options_Label_PrefsCurrentScheme,	"&Current Preferences Scheme")
 
-dcl(DLG_Options_Label_ShowSplash, "Show the AbiWord splash screen on application startup")
-
 dcl(DLG_Options_Label_CheckAutoLoadPlugins, "Automatically load all plugins found")
 
 dcl(DLG_Options_Label_ViewShowHide, 	"Show...")
@@ -922,6 +920,7 @@ dcl(MENU_LABEL_INSERT_FILE,"F&ile")
 dcl(MENU_LABEL_INSERT_SYMBOL,"Sy&mbol")
 dcl(MENU_LABEL_INSERT_ENDNOTE,"&Endnote")
 dcl(MENU_LABEL_INSERT_FOOTNOTE,"Foot&note")
+dcl(MENU_LABEL_INSERT_ANNOTATION,"Annotation")
 dcl(MENU_LABEL_INSERT_TABLEOFCONTENTS,"Table of Contents")
 dcl(MENU_LABEL_INSERT_CLIPART,"&Clip Art")
 dcl(MENU_LABEL_INSERT_GRAPHIC,"&Picture")
@@ -1191,6 +1190,7 @@ dcl(MENU_STATUSLINE_INSERT_MAILMERGE, "Insert a mail merge field")
 dcl(MENU_STATUSLINE_INSERT_FILE,"Insert the contents of another file")
 dcl(MENU_STATUSLINE_INSERT_SYMBOL,"Insert a symbol or other special character")
 dcl(MENU_STATUSLINE_INSERT_FOOTNOTE,"Insert a footnote")
+dcl(MENU_STATUSLINE_INSERT_ANNOTATION,"Insert an Annotation")
 dcl(MENU_STATUSLINE_INSERT_TABLEOFCONTENTS,"Insert a Table of Contents based on Headings")
 dcl(MENU_STATUSLINE_INSERT_ENDNOTE,"Insert an endnote")
 dcl(MENU_STATUSLINE_INSERT_CLIPART,"Insert clipart")
