@@ -19,6 +19,9 @@
  * 02111-1307, USA.
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -37,6 +40,8 @@
 
 #include "pd_Document.h"
 
+#include <gsf/gsf-output-impl.h>
+
 static UT_GenericVector<IE_ExpSniffer *> m_sniffers(20);
 
 /*****************************************************************/
@@ -62,7 +67,6 @@ public:
 	{
 		if (updatedFields_)
 			return;
-
 		// todo: support other platforms when possible
 		GR_Graphics * graphics = NULL;
 
@@ -172,8 +176,10 @@ void IE_Exp::unregisterAllExporters ()
 	{
 		pSniffer = m_sniffers.getNthItem(i);
 		if (pSniffer)
-			pSniffer->unref();
+			delete pSniffer;
 	}
+
+	m_sniffers.clear();
 }
 
 /*****************************************************************/
@@ -202,6 +208,9 @@ IE_Exp::~IE_Exp()
 
 void IE_Exp::populateFields()
 {
+	if(isCopying())
+		return;
+
 	if (!m_fieldUpdater)
 		m_fieldUpdater = new IE_FieldUpdater;
 
@@ -210,8 +219,13 @@ void IE_Exp::populateFields()
 
 void IE_Exp::setProps (const char * props)
 {
-	m_props_map.clear ();
-	m_props_map.parse_properties (props);
+	m_props_map.clear();
+	UT_parse_properties(props, m_props_map);
+}
+
+GsfOutput* IE_Exp::_openFile(const char *szFilename)
+{
+	return UT_go_file_create(szFilename, NULL);
 }
 
 GsfOutput* IE_Exp::openFile(const char * szFilename)
@@ -223,7 +237,12 @@ GsfOutput* IE_Exp::openFile(const char * szFilename)
 	m_szFileName = g_new(char, strlen(szFilename) + 1);
 	strcpy(m_szFileName, szFilename);
 
-	return UT_go_file_create(szFilename, NULL);
+	GsfOutput* file = _openFile(szFilename);
+	if (file) {
+		gsf_output_set_name (file, szFilename);
+	}
+
+	return file;
 }
 
 UT_uint32 IE_Exp::_writeBytes(const UT_Byte * pBytes, UT_uint32 length)
@@ -231,34 +250,50 @@ UT_uint32 IE_Exp::_writeBytes(const UT_Byte * pBytes, UT_uint32 length)
 	if(!pBytes || !length)
 	  return 0;
 
-	gsf_output_write(m_fp, length, pBytes);
+	if (!gsf_output_write(m_fp, length, pBytes))
+		return 0;
 	return length;
 }
 
 bool IE_Exp::_writeBytes(const UT_Byte * sz)
 {
-	int length = strlen(reinterpret_cast<const char *>(sz));
+	size_t length = strlen(reinterpret_cast<const char *>(sz));
 	return (_writeBytes(sz,length)==static_cast<UT_uint32>(length));
 }
 
 bool IE_Exp::_closeFile(void)
 {
 	if (m_fp && m_bOwnsFp) {
+		gboolean res = TRUE;
+
 		if(!gsf_output_is_closed(m_fp))
-			gsf_output_close(m_fp);
+			res = gsf_output_close(m_fp);
+
 		g_object_unref(G_OBJECT(m_fp));
 		m_fp = 0;
+
+		if (!res)
+			{
+				// then remove the unwritten file
+				(void)UT_go_file_remove (m_szFileName, NULL);
+			}
+
+		return (res == TRUE);
 	}
 	return true;
 }
 
 void IE_Exp::_abortFile(void)
 {
-	// abort the write.
-	// TODO close the file and do any restore and/or cleanup.
+	// abort the write
 	UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
-	_closeFile();
-	return;
+	if (m_fp)
+		{
+			_closeFile();
+			
+			// then remove the unwanted file
+			(void)UT_go_file_remove (m_szFileName, NULL);
+		}
 }
 
 //////////////////////////////////////////////////////////////////
@@ -301,7 +336,7 @@ UT_Error IE_Exp::writeFile(const char * szFilename)
 	UT_Error error = _writeDocument();
 
 	if (UT_OK == error)
-		_closeFile();
+		error = (_closeFile() ? UT_OK : UT_IE_COULDNOTWRITE);
 	else
 		_abortFile();
 
@@ -334,18 +369,7 @@ UT_Error IE_Exp::copyToBuffer(PD_DocumentRange * pDocRange, UT_ByteBuf * pBuf)
 
 void IE_Exp::write(const char * sz)
 {
-	if (m_error)
-		return;
-
-	if (!sz)
-		return;
-
-	if (m_pByteBuf)
-		m_error |= (m_pByteBuf->append(reinterpret_cast<const UT_Byte *>(sz),strlen(sz)) != true);
-	else
-		m_error |= ! _writeBytes(reinterpret_cast<const UT_Byte *>(sz));
-
-	return;
+	write(sz, strlen(sz));
 }
 
 /*! 
@@ -392,7 +416,10 @@ void IE_Exp::write(const char * sz, UT_uint32 length)
 IEFileType IE_Exp::fileTypeForMimetype(const char * szMimetype)
 {
 	if (!szMimetype)
+	{
+		UT_DEBUGMSG(("fileTypeForMimetype() no mimetype specified, defaulting to suffix .abw\n"));
 		return IE_Exp::fileTypeForSuffix(".abw");
+	}
 
 	// we have to construct the loop this way because a
 	// given filter could support more than one file type,
@@ -438,7 +465,10 @@ IEFileType IE_Exp::fileTypeForMimetype(const char * szMimetype)
 IEFileType IE_Exp::fileTypeForSuffix(const char * szSuffix)
 {
 	if (!szSuffix)
+	{
+		UT_DEBUGMSG(("fileTypeForSuffix() no suffix specified, defaulting to suffix .abw\n"));
 		return IE_Exp::fileTypeForSuffix(".abw");
+	}
 
 	// to alert us to bugs like 9571
 	UT_ASSERT_HARMLESS( *szSuffix == '.' );
