@@ -100,7 +100,7 @@ UT_Confidence_t IE_Exp_RTF_Sniffer::supportsMIME (const char * szMIME)
 {
 	if (strcmp (szMIME, IE_MIMETYPE_RTF) == 0)
 		{
-			return UT_CONFIDENCE_GOOD;
+			return UT_CONFIDENCE_PERFECT;
 		}
 	return UT_CONFIDENCE_ZILCH;
 }
@@ -671,7 +671,7 @@ bool IE_Exp_RTF::_write_rtf_header(void)
 		// NOTE:but we need convert them to CPxx.:-(
 		else
 		{
-			const char* codepage=XAP_EncodingManager::get_instance()->CodepageFromCharset(const_cast<char*>(cpgname));
+			const char* codepage=XAP_EncodingManager::get_instance()->CodepageFromCharset(cpgname);
 			if(g_ascii_strncasecmp(codepage,"cp",2)==0 && UT_UCS4_isdigit(codepage[2]))
 			{
 				int cpg;
@@ -1025,11 +1025,7 @@ bool IE_Exp_RTF::_write_rtf_header(void)
 		for(UT_uint32 i = 0; i < Revs.getItemCount(); ++i)
 		{
 			AD_Revision* pRev = Revs.getNthItem(i);
-			if(!pRev)
-			{
-				UT_ASSERT_HARMLESS( UT_SHOULD_NOT_HAPPEN );
-				continue;
-			}
+			UT_continue_if_fail(pRev);
 
 			s4 = pRev->getDescription();
 
@@ -1346,17 +1342,11 @@ void IE_Exp_RTF::_write_parafmt(const PP_AttrProp * pSpanAP, const PP_AttrProp *
 		else
 		{
 			const UT_UCSChar * lab = pAuto->getLabel(sdh);
-            //
-			// TODO Handle all our interesting symbols properly
-            // In the meantime convert to char *
-			static char tmp[100];
+
 			if(lab != NULL)
 			{
-				UT_uint32 len = UT_MIN(UT_UCS4_strlen(lab),100);
-				UT_uint32 i;
-				for(i=0; i<=len; i++)
-					tmp[i] = (char ) (unsigned char)  *lab++;
-				_rtf_chardata(tmp,len);
+				UT_UTF8String tmp = lab;
+				_rtf_chardata(tmp.utf8_str(),tmp.byteLength());
 			}
 			else
 			{
@@ -1916,11 +1906,7 @@ void IE_Exp_RTF::_output_revision(const s_RTF_AttrPropAdapter & apa, bool bPara,
 		for(UT_uint32 i = 0; i < RA.getRevisionsCount(); ++i)
 		{
 			const PP_Revision * pRev = RA.getNthRevision(i); // a revision found in our attribute
-			if(!pRev)
-			{
-				UT_ASSERT_HARMLESS( UT_SHOULD_NOT_HAPPEN );
-				continue;
-			}
+			UT_continue_if_fail(pRev);
 
 			UT_uint32 iId = pRev->getId();
 
@@ -1935,12 +1921,7 @@ void IE_Exp_RTF::_output_revision(const s_RTF_AttrPropAdapter & apa, bool bPara,
 			}
 
 			AD_Revision * pRevTblItem = RevTbl.getNthItem(iIndx);
-			if(!pRevTblItem)
-			{
-				UT_ASSERT_HARMLESS( UT_SHOULD_NOT_HAPPEN );
-				continue;
-			}
-			
+			UT_continue_if_fail(pRevTblItem);			
 			
 			// the revisions in rtf are marked by a peculiar timestamp, which we now need
 			// to construct
@@ -2056,11 +2037,7 @@ void IE_Exp_RTF::_output_revision(const s_RTF_AttrPropAdapter & apa, bool bPara,
 
 				if(bPara)
 				{
-					if(!sdh)
-					{
-						UT_ASSERT_HARMLESS( UT_SHOULD_NOT_HAPPEN );
-						continue;
-					}
+					UT_continue_if_fail(sdh);
 					
 					_write_parafmt(NULL, pRev, NULL,
 								   bStartedList, sdh, iCurrID, bIsListBlock, iNestLevel);
@@ -2299,14 +2276,14 @@ void IE_Exp_RTF::_write_stylesheets(void)
 
 		_write_style_fmt(pStyle);
 
-		const PD_Style * pStyleBasedOn =  reinterpret_cast<const PD_Style *> (const_cast<PD_Style *>(pStyle)->getBasedOn());
+		const PD_Style * pStyleBasedOn =  reinterpret_cast<const PD_Style *> (pStyle->getBasedOn());
 		// TODO: Can this really return NULL?
 		if (pStyleBasedOn != NULL)
 		{
 			_rtf_keyword("sbasedon", _getStyleNumber(pStyleBasedOn));
 		}
 
-		const PD_Style * pStyleNext = reinterpret_cast<const PD_Style *> (const_cast<PD_Style *>(pStyle)->getFollowedBy());
+		const PD_Style * pStyleNext = reinterpret_cast<const PD_Style *> (pStyle->getFollowedBy());
 		// TODO: Can this really return NULL?
 		if (pStyleNext != NULL)
 		{
@@ -3170,7 +3147,7 @@ bool _rtf_font_info::init(const s_RTF_AttrPropAdapter & apa, bool bDoFieldFont)
 	bool tt;
 	GR_Font::s_getGenericFontProperties((char*)szName, &ff, &fp, &tt);
 
-	if ((ff >= 0) && (ff < (int)NrElements(t_ff)))
+	if ((ff >= 0) && (ff < (int)G_N_ELEMENTS(t_ff)))
 		szFamily = t_ff[ff];
 	else
 		szFamily = t_ff[GR_Font::FF_Unknown];
@@ -3202,7 +3179,7 @@ bool _rtf_font_info::init(const char * szFontName)
     bool tt;
     GR_Font::s_getGenericFontProperties(m_szName.c_str(), &ff, &fp, &tt);
 
-    if ((ff >= 0) && (ff < (int)NrElements(t_ff)))
+    if ((ff >= 0) && (ff < (int)G_N_ELEMENTS(t_ff)))
 		szFamily = t_ff[ff];
     else
 		szFamily = t_ff[GR_Font::FF_Unknown];
